@@ -31,6 +31,7 @@ use nom7::{
     IResult,
 };
 
+/// cbindgen:ignore
 extern {
     fn ConfGet(key: *const c_char, res: *mut *const c_char) -> i8;
     fn ConfGetChildValue(conf: *const c_void, key: *const c_char,
@@ -81,13 +82,8 @@ pub fn conf_get(key: &str) -> Option<&str> {
 // Return the value of key as a boolean. A value that is not set is
 // the same as having it set to false.
 pub fn conf_get_bool(key: &str) -> bool {
-    if let Some(val) = conf_get(key) {
-        match val {
-            "1" | "yes" | "true" | "on" => {
-                return true;
-            },
-            _ => {},
-        }
+    if let Some("1" | "yes" | "true" | "on") = conf_get(key) {
+        return true;
     }
 
     return false;
