@@ -22,12 +22,12 @@ use crate::nfs::types::*;
 use crate::nfs::rpc_records::*;
 use crate::nfs::nfs2_records::*;
 
-use nom::IResult;
-use nom::number::streaming::be_u32;
+use nom7::IResult;
+use nom7::number::streaming::be_u32;
 
 impl NFSState {
     /// complete request record
-    pub fn process_request_record_v2<'b>(&mut self, r: &RpcPacket<'b>) {
+    pub fn process_request_record_v2(&mut self, r: &RpcPacket) {
         SCLogDebug!("NFSv2: REQUEST {} procedure {} ({}) blob size {}",
                 r.hdr.xid, r.procedure, self.requestmap.len(), r.prog_data.len());
 
@@ -74,6 +74,7 @@ impl NFSState {
             }
 
             tx.auth_type = r.creds_flavor;
+            #[allow(clippy::single_match)]
             match r.creds {
                 RpcRequestCreds::Unix(ref u) => {
                     tx.request_machine_name = u.machine_name_buf.to_vec();
@@ -91,7 +92,7 @@ impl NFSState {
         self.requestmap.insert(r.hdr.xid, xidmap);
     }
 
-    pub fn process_reply_record_v2<'b>(&mut self, r: &RpcReplyPacket<'b>, xidmap: &NFSRequestXidMap) {
+    pub fn process_reply_record_v2(&mut self, r: &RpcReplyPacket, xidmap: &NFSRequestXidMap) {
         let mut nfs_status = 0;
         let resp_handle = Vec::new();
 
@@ -99,7 +100,7 @@ impl NFSState {
             match parse_nfs2_reply_read(r.prog_data) {
                 Ok((_, ref reply)) => {
                     SCLogDebug!("NFSv2: READ reply record");
-                    self.process_read_record(r, reply, Some(&xidmap));
+                    self.process_read_record(r, reply, Some(xidmap));
                     nfs_status = reply.status;
                 },
                 _ => {
@@ -107,7 +108,7 @@ impl NFSState {
                 },
             }
         } else {
-            let stat : u32 = match be_u32(&r.prog_data) as IResult<&[u8],_> {
+            let stat : u32 = match be_u32(r.prog_data) as IResult<&[u8],_> {
                 Ok((_, stat)) => stat,
                 _ => 0
             };
