@@ -22,6 +22,7 @@ use crate::smb::dcerpc::*;
 use crate::smb::events::*;
 #[cfg(feature = "debug")]
 use crate::smb::funcs::*;
+use crate::smb::smb_status::*;
 
 #[derive(Debug)]
 pub struct SMBTransactionIoctl {
@@ -29,10 +30,10 @@ pub struct SMBTransactionIoctl {
 }
 
 impl SMBTransactionIoctl {
-    pub fn new(func: u32) -> SMBTransactionIoctl {
-        return SMBTransactionIoctl {
-            func: func,
-        }
+    pub fn new(func: u32) -> Self {
+        return Self {
+            func,
+        };
     }
 }
 
@@ -56,14 +57,16 @@ impl SMBState {
 }
 
 // IOCTL responses ASYNC don't set the tree id
-pub fn smb2_ioctl_request_record<'b>(state: &mut SMBState, r: &Smb2Record<'b>)
+pub fn smb2_ioctl_request_record(state: &mut SMBState, r: &Smb2Record)
 {
     let hdr = SMBCommonHdr::from2(r, SMBHDR_TYPE_HEADER);
     match parse_smb2_request_ioctl(r.data) {
         Ok((_, rd)) => {
             SCLogDebug!("IOCTL request data: {:?}", rd);
-            let is_dcerpc = rd.is_pipe && match state.get_service_for_guid(&rd.guid) {
-                (_, x) => x,
+            let is_dcerpc = if rd.is_pipe {
+                state.get_service_for_guid(rd.guid).1
+            } else {
+                false
             };
             if is_dcerpc {
                 SCLogDebug!("IOCTL request data is_pipe. Calling smb_write_dcerpc_record");
@@ -83,15 +86,17 @@ pub fn smb2_ioctl_request_record<'b>(state: &mut SMBState, r: &Smb2Record<'b>)
 }
 
 // IOCTL responses ASYNC don't set the tree id
-pub fn smb2_ioctl_response_record<'b>(state: &mut SMBState, r: &Smb2Record<'b>)
+pub fn smb2_ioctl_response_record(state: &mut SMBState, r: &Smb2Record)
 {
     let hdr = SMBCommonHdr::from2(r, SMBHDR_TYPE_HEADER);
     match parse_smb2_response_ioctl(r.data) {
         Ok((_, rd)) => {
             SCLogDebug!("IOCTL response data: {:?}", rd);
 
-            let is_dcerpc = rd.is_pipe && match state.get_service_for_guid(&rd.guid) {
-                (_, x) => x,
+            let is_dcerpc = if rd.is_pipe {
+                state.get_service_for_guid(rd.guid).1
+            } else {
+                false
             };
             if is_dcerpc {
                 SCLogDebug!("IOCTL response data is_pipe. Calling smb_read_dcerpc_record");
@@ -100,34 +105,28 @@ pub fn smb2_ioctl_response_record<'b>(state: &mut SMBState, r: &Smb2Record<'b>)
                 smb_read_dcerpc_record(state, vercmd, hdr, &[],rd.data);
             } else {
                 SCLogDebug!("SMB2_COMMAND_IOCTL/SMB_NTSTATUS_PENDING looking for {:?}", hdr);
-                match state.get_generic_tx(2, SMB2_COMMAND_IOCTL, &hdr) {
-                    Some(tx) => {
-                        tx.set_status(r.nt_status, false);
-                        if r.nt_status != SMB_NTSTATUS_PENDING {
-                            tx.response_done = true;
-                        }
-                    },
-                    None => { },
+                if let Some(tx) = state.get_generic_tx(2, SMB2_COMMAND_IOCTL, &hdr) {
+                    tx.set_status(r.nt_status, false);
+                    if r.nt_status != SMB_NTSTATUS_PENDING {
+                        tx.response_done = true;
+                    }
                 }
             }
         },
         _ => {
             SCLogDebug!("SMB2_COMMAND_IOCTL/SMB_NTSTATUS_PENDING looking for {:?}", hdr);
-            match state.get_generic_tx(2, SMB2_COMMAND_IOCTL, &hdr) {
-                Some(tx) => {
-                    SCLogDebug!("updated status of tx {}", tx.id);
-                    tx.set_status(r.nt_status, false);
-                    if r.nt_status != SMB_NTSTATUS_PENDING {
-                        tx.response_done = true;
-                    }
-
-                    // parsing failed for 'SUCCESS' record, set event
-                    if r.nt_status == SMB_NTSTATUS_SUCCESS {
-                        SCLogDebug!("parse fail {:?}", r);
-                        tx.set_event(SMBEvent::MalformedData);
-                    }
-                },
-                _ => { },
+            if let Some(tx) = state.get_generic_tx(2, SMB2_COMMAND_IOCTL, &hdr) {
+                SCLogDebug!("updated status of tx {}", tx.id);
+                tx.set_status(r.nt_status, false);
+                if r.nt_status != SMB_NTSTATUS_PENDING {
+                    tx.response_done = true;
+                }
+                
+                // parsing failed for 'SUCCESS' record, set event
+                if r.nt_status == SMB_NTSTATUS_SUCCESS {
+                    SCLogDebug!("parse fail {:?}", r);
+                    tx.set_event(SMBEvent::MalformedData);
+                }
             }
         },
     };
