@@ -54,7 +54,6 @@
 
 #include "queue.h"
 #include "suricata-common.h"
-#include "debug.h"
 
 #include "ippair-storage.h"
 #include "flow-storage.h"
@@ -72,7 +71,7 @@ SC_ATOMIC_DECLARE(uint32_t, expectation_count);
 #define EXPECTATION_MAX_LEVEL 10
 
 typedef struct Expectation_ {
-    struct timeval ts;
+    SCTime_t ts;
     Port sp;
     Port dp;
     AppProto alproto;
@@ -124,11 +123,11 @@ static void AppLayerFreeExpectation(Expectation *exp)
 static void ExpectationListFree(void *el)
 {
     ExpectationList *exp_list = (ExpectationList *)el;
-    Expectation *exp, *pexp;
     if (exp_list == NULL)
         return;
 
     if (exp_list->length > 0) {
+        Expectation *exp = NULL, *pexp = NULL;
         CIRCLEQ_FOREACH_SAFE(exp, &exp_list->list, entries, pexp) {
             CIRCLEQ_REMOVE(&exp_list->list, exp, entries);
             exp_list->length--;
@@ -245,7 +244,7 @@ int AppLayerExpectationCreate(Flow *f, int direction, Port src, Port dst,
     exp_list = IPPairGetStorageById(ipp, g_ippair_expectation_id);
     if (exp_list) {
         CIRCLEQ_INSERT_HEAD(&exp_list->list, exp, entries);
-        /* In case there is already EXPECTATION_MAX_LEVEL expectations waiting to be fullfill,
+        /* In case there is already EXPECTATION_MAX_LEVEL expectations waiting to be fulfilled,
          * we remove the older expectation to limit the total number of expectations */
         if (exp_list->length >= EXPECTATION_MAX_LEVEL) {
             Expectation *last_exp = CIRCLEQ_LAST(&exp_list->list);
@@ -318,8 +317,6 @@ AppProto AppLayerExpectationHandle(Flow *f, uint8_t flags)
     if (exp_list == NULL)
         goto out;
 
-    time_t ctime = f->lastts.tv_sec;
-
     CIRCLEQ_FOREACH_SAFE(exp, &exp_list->list, entries, lexp) {
         if ((exp->direction & flags) && ((exp->sp == 0) || (exp->sp == f->sp)) &&
                 ((exp->dp == 0) || (exp->dp == f->dp))) {
@@ -347,7 +344,7 @@ AppProto AppLayerExpectationHandle(Flow *f, uint8_t flags)
             continue;
         }
         /* Cleaning remove old entries */
-        if (ctime > exp->ts.tv_sec + EXPECTATION_TIMEOUT) {
+        if (SCTIME_SECS(f->lastts) > SCTIME_SECS(exp->ts) + EXPECTATION_TIMEOUT) {
             exp_list = AppLayerExpectationRemove(ipp, exp_list, exp);
             if (exp_list == NULL)
                 goto out;
