@@ -1,4 +1,4 @@
-/* Copyright (C) 2007-2013 Open Information Security Foundation
+/* Copyright (C) 2007-2021 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -27,7 +27,7 @@
 
 enum AppProtoEnum {
     ALPROTO_UNKNOWN = 0,
-    ALPROTO_HTTP,
+    ALPROTO_HTTP1,
     ALPROTO_FTP,
     ALPROTO_SMTP,
     ALPROTO_TLS, /* SSLv2, SSLv3 & TLSv1 */
@@ -46,17 +46,24 @@ enum AppProtoEnum {
     ALPROTO_NTP,
     ALPROTO_FTPDATA,
     ALPROTO_TFTP,
-    ALPROTO_IKEV2,
+    ALPROTO_IKE,
     ALPROTO_KRB5,
+    ALPROTO_QUIC,
     ALPROTO_DHCP,
     ALPROTO_SNMP,
     ALPROTO_SIP,
     ALPROTO_RFB,
     ALPROTO_MQTT,
+    ALPROTO_PGSQL,
+    ALPROTO_TELNET,
     ALPROTO_TEMPLATE,
-    ALPROTO_TEMPLATE_RUST,
     ALPROTO_RDP,
     ALPROTO_HTTP2,
+    ALPROTO_BITTORRENT_DHT,
+
+    // signature-only (ie not seen in flow)
+    // HTTP for any version (ALPROTO_HTTP1 (version 1) or ALPROTO_HTTP2)
+    ALPROTO_HTTP,
 
     /* used by the probing parser when alproto detection fails
      * permanently for that particular stream */
@@ -77,16 +84,15 @@ static inline bool AppProtoIsValid(AppProto a)
     return ((a > ALPROTO_UNKNOWN && a < ALPROTO_FAILED));
 }
 
-extern bool g_config_http1keywords_http2traffic;
-
-// wether a signature AppProto matches a flow (or signature) AppProto
+// whether a signature AppProto matches a flow (or signature) AppProto
 static inline bool AppProtoEquals(AppProto sigproto, AppProto alproto)
 {
-    if (alproto == ALPROTO_HTTP2 && g_config_http1keywords_http2traffic &&
-            sigproto == ALPROTO_HTTP) {
-        return true;
-    } else if (sigproto == ALPROTO_DCERPC) {
-        return (alproto == ALPROTO_DCERPC || alproto == ALPROTO_SMB);
+    switch (sigproto) {
+        case ALPROTO_HTTP:
+            return (alproto == ALPROTO_HTTP1) || (alproto == ALPROTO_HTTP2) ||
+                   (alproto == ALPROTO_HTTP);
+        case ALPROTO_DCERPC:
+            return (alproto == ALPROTO_DCERPC || alproto == ALPROTO_SMB);
     }
     return (sigproto == alproto);
 }
