@@ -24,6 +24,7 @@
  */
 
 #include "suricata-common.h"
+#include "suricata.h"
 #include "stream.h"
 #include "conf.h"
 
@@ -40,21 +41,24 @@ AppProto AppLayerRegisterProtocolDetection(const struct AppLayerParser *p, int e
     const char *ip_proto_str = NULL;
 
     if (p == NULL)
-        FatalError(SC_ERR_FATAL, "Call to %s with NULL pointer.", __FUNCTION__);
+        FatalError("Call to %s with NULL pointer.", __FUNCTION__);
 
     alproto = StringToAppProto(p->name);
     if (alproto == ALPROTO_UNKNOWN || alproto == ALPROTO_FAILED)
-        FatalError(SC_ERR_FATAL, "Unknown or invalid AppProto '%s'.", p->name);
+        FatalError("Unknown or invalid AppProto '%s'.", p->name);
+
+    BUG_ON(strcmp(p->name, AppProtoToString(alproto)) != 0);
 
     ip_proto_str = IpProtoToString(p->ip_proto);
     if (ip_proto_str == NULL)
-        FatalError(SC_ERR_FATAL, "Unknown or unsupported ip_proto field in parser '%s'", p->name);
+        FatalError("Unknown or unsupported ip_proto field in parser '%s'", p->name);
 
     SCLogDebug("%s %s protocol detection enabled.", ip_proto_str, p->name);
 
     AppLayerProtoDetectRegisterProtocol(alproto, p->name);
 
     if (p->ProbeTS == NULL && p->ProbeTC == NULL) {
+        BUG_ON(p->default_port != NULL);
         return alproto;
     }
 
@@ -95,14 +99,16 @@ int AppLayerRegisterParser(const struct AppLayerParser *p, AppProto alproto)
     const char *ip_proto_str = NULL;
 
     if (p == NULL)
-        FatalError(SC_ERR_FATAL, "Call to %s with NULL pointer.", __FUNCTION__);
+        FatalError("Call to %s with NULL pointer.", __FUNCTION__);
 
     if (alproto == ALPROTO_UNKNOWN || alproto >= ALPROTO_FAILED)
-        FatalError(SC_ERR_FATAL, "Unknown or invalid AppProto '%s'.", p->name);
+        FatalError("Unknown or invalid AppProto '%s'.", p->name);
+
+    BUG_ON(strcmp(p->name, AppProtoToString(alproto)) != 0);
 
     ip_proto_str = IpProtoToString(p->ip_proto);
     if (ip_proto_str == NULL)
-        FatalError(SC_ERR_FATAL, "Unknown or unsupported ip_proto field in parser '%s'", p->name);
+        FatalError("Unknown or unsupported ip_proto field in parser '%s'", p->name);
 
     SCLogDebug("Registering %s protocol parser.", p->name);
 
@@ -129,17 +135,13 @@ int AppLayerRegisterParser(const struct AppLayerParser *p, AppProto alproto)
         p->StateGetTxCnt);
 
     /* Transaction handling. */
-    AppLayerParserRegisterGetStateProgressCompletionStatus(alproto,
-        p->StateGetProgressCompletionStatus);
+    AppLayerParserRegisterStateProgressCompletionStatus(alproto, p->complete_ts, p->complete_tc);
+
     AppLayerParserRegisterGetStateProgressFunc(p->ip_proto, alproto,
         p->StateGetProgress);
     AppLayerParserRegisterGetTx(p->ip_proto, alproto,
         p->StateGetTx);
 
-    /* What is this being registered for? */
-    AppLayerParserRegisterDetectStateFuncs(p->ip_proto, alproto,
-        p->GetTxDetectState, p->SetTxDetectState);
-
     if (p->StateGetEventInfo) {
         AppLayerParserRegisterGetEventInfo(p->ip_proto, alproto,
                 p->StateGetEventInfo);
@@ -148,17 +150,12 @@ int AppLayerRegisterParser(const struct AppLayerParser *p, AppProto alproto)
         AppLayerParserRegisterGetEventInfoById(p->ip_proto, alproto,
                 p->StateGetEventInfoById);
     }
-    if (p->StateGetEvents) {
-        AppLayerParserRegisterGetEventsFunc(p->ip_proto, alproto,
-                p->StateGetEvents);
-    }
     if (p->LocalStorageAlloc && p->LocalStorageFree) {
         AppLayerParserRegisterLocalStorageFunc(p->ip_proto, alproto,
                 p->LocalStorageAlloc, p->LocalStorageFree);
     }
-    if (p->StateGetFiles) {
-        AppLayerParserRegisterGetFilesFunc(p->ip_proto, alproto,
-                p->StateGetFiles);
+    if (p->GetTxFiles) {
+        AppLayerParserRegisterGetTxFilesFunc(p->ip_proto, alproto, p->GetTxFiles);
     }
 
     if (p->GetTxIterator) {
@@ -171,6 +168,10 @@ int AppLayerRegisterParser(const struct AppLayerParser *p, AppProto alproto)
                 p->GetTxData);
     }
 
+    if (p->GetStateData) {
+        AppLayerParserRegisterStateDataFunc(p->ip_proto, alproto, p->GetStateData);
+    }
+
     if (p->ApplyTxConfig) {
         AppLayerParserRegisterApplyTxConfigFunc(p->ip_proto, alproto,
                 p->ApplyTxConfig);
@@ -186,6 +187,18 @@ int AppLayerRegisterParser(const struct AppLayerParser *p, AppProto alproto)
         AppLayerParserRegisterTruncateFunc(p->ip_proto, alproto, p->Truncate);
     }
 
+    if (p->GetFrameIdByName && p->GetFrameNameById) {
+        AppLayerParserRegisterGetFrameFuncs(
+                p->ip_proto, alproto, p->GetFrameIdByName, p->GetFrameNameById);
+    }
+
+    return 0;
+}
+
+int AppLayerRegisterParserAlias(const char *proto_name, const char *proto_alias)
+{
+    AppLayerProtoDetectRegisterAlias(proto_name, proto_alias);
+
     return 0;
 }
 
