@@ -34,8 +34,7 @@
 #include "app-layer-parser.h"
 
 #include "app-layer-snmp.h"
-
-#include "rust-snmp-snmp-gen.h"
+#include "rust.h"
 
 void RegisterSNMPParsers(void)
 {
