@@ -19,7 +19,7 @@
 #define __DECODE_TEREDO_H__
 
 int DecodeTeredo(ThreadVars *tv, DecodeThreadVars *dtv, Packet *p,
-                 const uint8_t *pkt, uint16_t len, PacketQueue *pq);
+                 const uint8_t *pkt, uint16_t len);
 void DecodeTeredoConfig(void);
 bool DecodeTeredoEnabledForPort(const uint16_t sp, const uint16_t dp);
 
