@@ -1,4 +1,4 @@
-/* Copyright (C) 2007-2012 Open Information Security Foundation
+/* Copyright (C) 2007-2023 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -26,6 +26,7 @@
 
 #include "decode.h"
 #include "defrag.h"
+#include "util-exception-policy.h"
 
 /** Spinlocks or Mutex for the flow buckets. */
 //#define DRLOCK_SPIN
@@ -64,9 +65,6 @@ typedef struct DefragTrackerHashRow_ {
 /** defrag tracker hash table */
 extern DefragTrackerHashRow *defragtracker_hash;
 
-#define DEFRAG_VERBOSE    0
-#define DEFRAG_QUIET      1
-
 typedef struct DefragConfig_ {
     SC_ATOMIC_DECLARE(uint64_t, memcap);
     uint32_t hash_rand;
@@ -90,7 +88,7 @@ SC_ATOMIC_EXTERN(uint64_t,defrag_memuse);
 SC_ATOMIC_EXTERN(unsigned int,defragtracker_counter);
 SC_ATOMIC_EXTERN(unsigned int,defragtracker_prune_idx);
 
-void DefragInitConfig(char quiet);
+void DefragInitConfig(bool quiet);
 void DefragHashShutdown(void);
 
 DefragTracker *DefragLookupTrackerFromHash (Packet *);
