@@ -24,8 +24,6 @@
  */
 
 #include "suricata-common.h"
-#include "threads.h"
-#include "debug.h"
 #include "defrag-queue.h"
 #include "util-error.h"
 #include "util-debug.h"
@@ -44,7 +42,7 @@ DefragTrackerQueue *DefragTrackerQueueNew(void)
 {
     DefragTrackerQueue *q = (DefragTrackerQueue *)SCMalloc(sizeof(DefragTrackerQueue));
     if (q == NULL) {
-        SCLogError(SC_ERR_FATAL, "Fatal error encountered in DefragTrackerQueueNew. Exiting...");
+        SCLogError("Fatal error encountered in DefragTrackerQueueNew. Exiting...");
         exit(EXIT_SUCCESS);
     }
     q = DefragTrackerQueueInit(q);
