@@ -1,4 +1,4 @@
-/* Copyright (C) 2015 Open Information Security Foundation
+/* Copyright (C) 2015-2022 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -25,6 +25,7 @@
 #include "suricata-common.h"
 
 #include "app-layer.h"
+#include "app-layer-enip-common.h"
 
 #include "detect.h"
 #include "detect-cipservice.h"
@@ -157,7 +158,7 @@ static int CIPPathMatch(CIPServiceEntry *svc, DetectCipServiceData *cipserviced)
 
 /**
  * \brief Matches the rule to the ENIP Transaction
- * @param enip_data - the ENIP transation
+ * @param enip_data - the ENIP transaction
  * * @param cipserviced - the CIP service rule
  */
 
@@ -221,16 +222,15 @@ static int CIPServiceMatch(ENIPTransaction *enip_data,
  *
  *  \retval 0 no match or 1 match
  */
-int DetectEngineInspectCIP(ThreadVars *tv,
-        DetectEngineCtx *de_ctx, DetectEngineThreadCtx *det_ctx,
-        const Signature *s, const SigMatchData *smd, Flow *f, uint8_t flags,
-        void *alstate, void *txv, uint64_t tx_id)
+uint8_t DetectEngineInspectCIP(DetectEngineCtx *de_ctx, DetectEngineThreadCtx *det_ctx,
+        const struct DetectEngineAppInspectionEngine_ *engine, const Signature *s, Flow *f,
+        uint8_t flags, void *alstate, void *txv, uint64_t tx_id)
 {
     SCEnter();
 
 
     ENIPTransaction *tx = (ENIPTransaction *) txv;
-    DetectCipServiceData *cipserviced = (DetectCipServiceData *) smd->ctx;
+    DetectCipServiceData *cipserviced = (DetectCipServiceData *)engine->smd->ctx;
 
     if (cipserviced == NULL)
     {
@@ -261,15 +261,14 @@ int DetectEngineInspectCIP(ThreadVars *tv,
  *  \retval 0 no match or 1 match
  */
 
-int DetectEngineInspectENIP(ThreadVars *tv,
-        DetectEngineCtx *de_ctx, DetectEngineThreadCtx *det_ctx,
-        const Signature *s, const SigMatchData *smd,
-        Flow *f, uint8_t flags, void *alstate, void *txv, uint64_t tx_id)
+uint8_t DetectEngineInspectENIP(DetectEngineCtx *de_ctx, DetectEngineThreadCtx *det_ctx,
+        const struct DetectEngineAppInspectionEngine_ *engine, const Signature *s, Flow *f,
+        uint8_t flags, void *alstate, void *txv, uint64_t tx_id)
 {
     SCEnter();
 
     ENIPTransaction *tx = (ENIPTransaction *) txv;
-    DetectEnipCommandData *enipcmdd = (DetectEnipCommandData *) smd->ctx;
+    DetectEnipCommandData *enipcmdd = (DetectEnipCommandData *)engine->smd->ctx;
 
     if (enipcmdd == NULL)
     {
@@ -287,96 +286,3 @@ int DetectEngineInspectENIP(ThreadVars *tv,
 
     SCReturnInt(0);
 }
-
-#ifdef UNITTESTS /* UNITTESTS */
-#include "app-layer-parser.h"
-#include "detect-parse.h"
-#include "detect-engine.h"
-#include "flow-util.h"
-#include "stream-tcp.h"
-#include "util-unittest.h"
-#include "util-unittest-helper.h"
-
-static uint8_t listIdentity[] = {/* List ID */    0x00, 0x63,
-                                 /* Length */     0x00, 0x00,
-                                 /* Session */    0x00, 0x00, 0x00, 0x00,
-                                 /* Status */     0x00, 0x00, 0x00, 0x00,
-                                 /*  Delay*/      0x00,
-                                 /* Context */    0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-                                 /* Quantity of coils */ 0x00, 0x00, 0x00, 0x00,};
-
-/** \test Test code function. */
-static int DetectEngineInspectENIPTest01(void)
-{
-    AppLayerParserThreadCtx *alp_tctx = AppLayerParserThreadCtxAlloc();
-    DetectEngineThreadCtx *det_ctx = NULL;
-    DetectEngineCtx *de_ctx = NULL;
-    Flow f;
-    Packet *p = NULL;
-    Signature *s = NULL;
-    TcpSession ssn;
-    ThreadVars tv;
-
-    memset(&tv, 0, sizeof(ThreadVars));
-    memset(&f, 0, sizeof(Flow));
-    memset(&ssn, 0, sizeof(TcpSession));
-
-    p = UTHBuildPacket(listIdentity, sizeof(listIdentity), IPPROTO_TCP);
-    FAIL_IF_NULL(p);
-
-    FLOW_INITIALIZE(&f);
-    f.alproto   = ALPROTO_ENIP;
-    f.protoctx  = (void *)&ssn;
-    f.proto     = IPPROTO_TCP;
-    f.flags     |= FLOW_IPV4;
-
-    p->flow         = &f;
-    p->flags        |= PKT_HAS_FLOW | PKT_STREAM_EST;
-    p->flowflags    |= FLOW_PKT_TOSERVER | FLOW_PKT_ESTABLISHED;
-
-    StreamTcpInitConfig(TRUE);
-
-    de_ctx = DetectEngineCtxInit();
-    FAIL_IF_NULL(de_ctx);
-
-    de_ctx->flags |= DE_QUIET;
-    s = de_ctx->sig_list = SigInit(de_ctx, "alert enip any any -> any any "
-            "(msg:\"Testing enip command\"; "
-            "enipcommand:99 ; sid:1;)");
-    FAIL_IF_NULL(s);
-
-    SigGroupBuild(de_ctx);
-    DetectEngineThreadCtxInit(&tv, (void *)de_ctx, (void *)&det_ctx);
-
-    int r = AppLayerParserParse(NULL, alp_tctx, &f, ALPROTO_ENIP, STREAM_TOSERVER,
-            listIdentity, sizeof(listIdentity));
-    FAIL_IF(r != 0);
-
-    ENIPState    *enip_state = f.alstate;
-    FAIL_IF_NULL(enip_state);
-
-    /* do detect */
-    SigMatchSignatures(&tv, de_ctx, det_ctx, p);
-
-    FAIL_IF(!(PacketAlertCheck(p, 1)));
-
-    AppLayerParserThreadCtxFree(alp_tctx);
-    DetectEngineThreadCtxDeinit(&tv, det_ctx);
-    DetectEngineCtxFree(de_ctx);
-
-    StreamTcpFreeConfig(TRUE);
-    FLOW_DESTROY(&f);
-    UTHFreePacket(p);
-
-    PASS;
-}
-
-#endif /* UNITTESTS */
-
-void DetectEngineInspectENIPRegisterTests(void)
-{
-#ifdef UNITTESTS
-    UtRegisterTest("DetectEngineInspectENIPTest01", DetectEngineInspectENIPTest01);
-#endif /* UNITTESTS */
-    return;
-}
