@@ -1,4 +1,4 @@
-/* Copyright (C) 2007-2022 Open Information Security Foundation
+/* Copyright (C) 2007-2021 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -130,22 +130,22 @@ static DetectEngineEventData *DetectEngineEventParse (const char *rawstr)
 {
     int i;
     DetectEngineEventData *de = NULL;
-    int ret = 0, res = 0, found = 0;
-    int ov[MAX_SUBSTRINGS];
+    int res = 0, found = 0;
+    size_t pcre2len;
+    pcre2_match_data *match = NULL;
 
-    ret = DetectParsePcreExec(&parse_regex, rawstr, 0, 0, ov, MAX_SUBSTRINGS);
+    int ret = DetectParsePcreExec(&parse_regex, &match, rawstr, 0, 0);
     if (ret < 1) {
-        SCLogError(SC_ERR_PCRE_MATCH, "pcre_exec parse error, ret %" PRId32
-                ", string %s", ret, rawstr);
+        SCLogError("pcre_exec parse error, ret %" PRId32 ", string %s", ret, rawstr);
         goto error;
     }
 
     char copy_str[128] = "";
-    res = pcre_copy_substring((char *)rawstr, ov, MAX_SUBSTRINGS, 0,
-            copy_str, sizeof(copy_str));
+    pcre2len = sizeof(copy_str);
+    res = pcre2_substring_copy_bynumber(match, 0, (PCRE2_UCHAR8 *)copy_str, &pcre2len);
 
     if (res < 0) {
-        SCLogError(SC_ERR_PCRE_GET_SUBSTRING, "pcre_copy_substring failed");
+        SCLogError("pcre2_substring_copy_bynumber failed");
         goto error;
     }
 
@@ -157,8 +157,7 @@ static DetectEngineEventData *DetectEngineEventParse (const char *rawstr)
     }
 
     if (found == 0) {
-        SCLogError(SC_ERR_UNKNOWN_DECODE_EVENT, "unknown decode event \"%s\"",
-                copy_str);
+        SCLogError("unknown decode event \"%s\"", copy_str);
         goto error;
     }
 
@@ -174,19 +173,22 @@ static DetectEngineEventData *DetectEngineEventParse (const char *rawstr)
 
     if (OutdatedEvent(rawstr)) {
         if (SigMatchStrictEnabled(DETECT_DECODE_EVENT)) {
-            SCLogError(SC_WARN_DEPRECATED, "decode-event keyword no longer supports event \"%s\"",
-                    rawstr);
+            SCLogError("decode-event keyword no longer supports event \"%s\"", rawstr);
             goto error;
         } else {
-            SCLogNotice("decode-event keyword no longer supports event \"%s\"", rawstr);
+            SCLogWarning("decode-event keyword no longer supports event \"%s\"", rawstr);
         }
     }
 
+    pcre2_match_data_free(match);
     return de;
 
 error:
     if (de)
         SCFree(de);
+    if (match) {
+        pcre2_match_data_free(match);
+    }
     return NULL;
 }
 
@@ -200,8 +202,8 @@ error:
  * \retval 0 on Success
  * \retval -1 on Failure
  */
-static int DetectEngineEventSetupDo (DetectEngineCtx *de_ctx, Signature *s,
-        const char *rawstr, int smtype)
+static int DetectEngineEventSetupDo(
+        DetectEngineCtx *de_ctx, Signature *s, const char *rawstr, uint16_t smtype)
 {
     DetectEngineEventData *de = DetectEngineEventParse(rawstr);
     if (de == NULL)
@@ -284,14 +286,13 @@ static int DetectStreamEventSetup (DetectEngineCtx *de_ctx, Signature *s, const
  */
 static int EngineEventTestParse01 (void)
 {
-    DetectEngineEventData *de = NULL;
-    de = DetectEngineEventParse("decoder.ipv4.pkt_too_small");
-    if (de) {
-        DetectEngineEventFree(NULL, de);
-        return 1;
-    }
+    DetectEngineEventData *de = DetectEngineEventParse("decoder.ipv4.pkt_too_small");
 
-    return 0;
+    FAIL_IF_NULL(de);
+
+    DetectEngineEventFree(NULL, de);
+
+    PASS;
 }
 
 
@@ -300,14 +301,13 @@ static int EngineEventTestParse01 (void)
  */
 static int EngineEventTestParse02 (void)
 {
-    DetectEngineEventData *de = NULL;
-    de = DetectEngineEventParse("decoder.PPP.pkt_too_small");
-    if (de) {
-        DetectEngineEventFree(NULL, de);
-        return 1;
-    }
+    DetectEngineEventData *de = DetectEngineEventParse("decoder.PPP.pkt_too_small");
 
-    return 0;
+    FAIL_IF_NULL(de);
+
+    DetectEngineEventFree(NULL, de);
+
+    PASS;
 }
 
 /**
@@ -315,14 +315,13 @@ static int EngineEventTestParse02 (void)
  */
 static int EngineEventTestParse03 (void)
 {
-    DetectEngineEventData *de = NULL;
-    de = DetectEngineEventParse("decoder.IPV6.PKT_TOO_SMALL");
-    if (de) {
-        DetectEngineEventFree(NULL, de);
-        return 1;
-    }
+    DetectEngineEventData *de = DetectEngineEventParse("decoder.IPV6.PKT_TOO_SMALL");
 
-    return 0;
+    FAIL_IF_NULL(de);
+
+    DetectEngineEventFree(NULL, de);
+
+    PASS;
 }
 
 /**
@@ -330,14 +329,13 @@ static int EngineEventTestParse03 (void)
  */
 static int EngineEventTestParse04 (void)
 {
-    DetectEngineEventData *de = NULL;
-    de = DetectEngineEventParse("decoder.IPV6.INVALID_EVENT");
-    if (de) {
-        DetectEngineEventFree(NULL, de);
-        return 0;
-    }
+    DetectEngineEventData *de = DetectEngineEventParse("decoder.IPV6.INVALID_EVENT");
 
-    return 1;
+    FAIL_IF_NOT_NULL(de);
+
+    DetectEngineEventFree(NULL, de);
+
+    PASS;
 }
 
 /**
@@ -345,14 +343,13 @@ static int EngineEventTestParse04 (void)
  */
 static int EngineEventTestParse05 (void)
 {
-    DetectEngineEventData *de = NULL;
-    de = DetectEngineEventParse("decoder.IPV-6,INVALID_CHAR");
-    if (de) {
-        DetectEngineEventFree(NULL, de);
-        return 0;
-    }
+    DetectEngineEventData *de = DetectEngineEventParse("decoder.IPV-6,INVALID_CHAR");
 
-    return 1;
+    FAIL_IF_NOT_NULL(de);
+
+    DetectEngineEventFree(NULL, de);
+
+    PASS;
 }
 
 /**
@@ -361,43 +358,32 @@ static int EngineEventTestParse05 (void)
 static int EngineEventTestParse06 (void)
 {
     Packet *p = PacketGetFromAlloc();
-    if (unlikely(p == NULL))
-        return 0;
-    ThreadVars tv;
-    int ret = 0;
-    DetectEngineEventData *de = NULL;
-    SigMatch *sm = NULL;
+    FAIL_IF_NULL(p);
 
+    ThreadVars tv;
 
     memset(&tv, 0, sizeof(ThreadVars));
 
     ENGINE_SET_EVENT(p,PPP_PKT_TOO_SMALL);
 
-    de = DetectEngineEventParse("decoder.ppp.pkt_too_small");
-    if (de == NULL)
-        goto error;
+    DetectEngineEventData *de = DetectEngineEventParse("decoder.ppp.pkt_too_small");
+    FAIL_IF_NULL(de);
 
     de->event = PPP_PKT_TOO_SMALL;
 
-    sm = SigMatchAlloc();
-    if (sm == NULL)
-        goto error;
+    SigMatch *sm = SigMatchAlloc();
+    FAIL_IF_NULL(sm);
 
     sm->type = DETECT_DECODE_EVENT;
     sm->ctx = (SigMatchCtx *)de;
 
-    ret = DetectEngineEventMatch(NULL,p,NULL,sm->ctx);
+    FAIL_IF_NOT(DetectEngineEventMatch(NULL, p, NULL, sm->ctx));
 
-    if(ret) {
-        SCFree(p);
-        return 1;
-    }
-
-error:
-    if (de) SCFree(de);
-    if (sm) SCFree(sm);
     SCFree(p);
-    return 0;
+    SCFree(de);
+    SCFree(sm);
+
+    PASS;
 }
 
 /**
