@@ -1,4 +1,4 @@
-/* Copyright (C) 2007-2013 Open Information Security Foundation
+/* Copyright (C) 2007-2021 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -32,6 +32,7 @@
 #include "util-time.h"
 #include "util-hashlist.h"
 #include "detect-engine-tag.h"
+#include "detect-engine-build.h"
 #include "detect-tag.h"
 #include "host.h"
 #include "host-storage.h"
@@ -45,7 +46,7 @@
 SC_ATOMIC_DECLARE(unsigned int, num_tags);  /**< Atomic counter, to know if we
                                                  have tagged hosts/sessions,
                                                  to avoid locking */
-static int host_tag_id = -1;                /**< Host storage id for tags */
+static HostStorageId host_tag_id = { .id = -1 }; /**< Host storage id for tags */
 static FlowStorageId flow_tag_id = { .id = -1 }; /**< Flow storage id for tags */
 
 void TagInitCtx(void)
@@ -53,12 +54,12 @@ void TagInitCtx(void)
     SC_ATOMIC_INIT(num_tags);
 
     host_tag_id = HostStorageRegister("tag", sizeof(void *), NULL, DetectTagDataListFree);
-    if (host_tag_id == -1) {
-        FatalError(SC_ERR_FATAL, "Can't initiate host storage for tag");
+    if (host_tag_id.id == -1) {
+        FatalError("Can't initiate host storage for tag");
     }
     flow_tag_id = FlowStorageRegister("tag", sizeof(void *), NULL, DetectTagDataListFree);
     if (flow_tag_id.id == -1) {
-        FatalError(SC_ERR_FATAL, "Can't initiate flow storage for tag");
+        FatalError("Can't initiate flow storage for tag");
     }
 }
 
@@ -117,7 +118,7 @@ static DetectTagDataEntry *DetectTagDataCopy(DetectTagDataEntry *dtd)
  * \param p pointer to the current packet
  * \param tde pointer to the new DetectTagDataEntry
  *
- * \retval 0 if the tde was added succesfuly
+ * \retval 0 if the tde was added successfully
  * \retval 1 if an entry of this sid/gid already exist and was updated
  */
 int TagFlowAdd(Packet *p, DetectTagDataEntry *tde)
@@ -262,7 +263,7 @@ static void TagHandlePacketFlow(Flow *f, Packet *p)
 
     while (iter != NULL) {
         /* update counters */
-        iter->last_ts = p->ts.tv_sec;
+        iter->last_ts = SCTIME_SECS(p->ts);
         switch (iter->metric) {
             case DETECT_TAG_METRIC_PACKET:
                 iter->packets++;
@@ -276,6 +277,7 @@ static void TagHandlePacketFlow(Flow *f, Packet *p)
          * to log it (the alert will log it) */
         if (!(iter->flags & TAG_ENTRY_FLAG_SKIPPED_FIRST)) {
             iter->flags |= TAG_ENTRY_FLAG_SKIPPED_FIRST;
+            p->flags |= PKT_FIRST_TAG;
         } else {
             /* Update metrics; remove if tag expired; and set alerts */
             switch (iter->metric) {
@@ -383,7 +385,7 @@ static void TagHandlePacketHost(Host *host, Packet *p)
     prev = NULL;
     while (iter != NULL) {
         /* update counters */
-        iter->last_ts = p->ts.tv_sec;
+        iter->last_ts = SCTIME_SECS(p->ts);
         switch (iter->metric) {
             case DETECT_TAG_METRIC_PACKET:
                 iter->packets++;
@@ -532,7 +534,7 @@ void TagHandlePacket(DetectEngineCtx *de_ctx,
 }
 
 /**
- * \brief Removes the entries exceding the max timeout value
+ * \brief Removes the entries exceeding the max timeout value
  *
  * \param tag_ctx Tag context
  * \param ts the current time
@@ -540,7 +542,7 @@ void TagHandlePacket(DetectEngineCtx *de_ctx,
  * \retval 1 no tags or tags removed -- host is free to go (from tag perspective)
  * \retval 0 still active tags
  */
-int TagTimeoutCheck(Host *host, struct timeval *tv)
+int TagTimeoutCheck(Host *host, SCTime_t ts)
 {
     DetectTagDataEntry *tde = NULL;
     DetectTagDataEntry *tmp = NULL;
@@ -553,9 +555,8 @@ int TagTimeoutCheck(Host *host, struct timeval *tv)
 
     prev = NULL;
     while (tmp != NULL) {
-        struct timeval last_ts = { .tv_sec = tmp->last_ts, 0 };
-        struct timeval timeout_at = TimevalWithSeconds(&last_ts, TAG_MAX_LAST_TIME_SEEN);
-        if (!TimevalEarlier(&timeout_at, tv)) {
+        SCTime_t timeout_at = SCTIME_FROM_SECS(tmp->last_ts + TAG_MAX_LAST_TIME_SEEN);
+        if (SCTIME_CMP_GTE(timeout_at, ts)) {
             prev = tmp;
             tmp = tmp->next;
             retval = 0;
@@ -592,7 +593,6 @@ int TagTimeoutCheck(Host *host, struct timeval *tv)
  */
 static int DetectTagTestPacket01 (void)
 {
-    int result = 0;
     uint8_t *buf = (uint8_t *)"Hi all!";
     uint8_t *buf2 = (uint8_t *)"lalala!";
     uint16_t buf_len = strlen((char *)buf);
@@ -646,42 +646,36 @@ static int DetectTagTestPacket01 (void)
     HostInitConfig(1);
 
     SCLogDebug("running tests");
-    result = UTHGenericTest(p, 7, sigs, sid, (uint32_t *) results, 5);
+    FAIL_IF_NOT(UTHGenericTest(p, 7, sigs, sid, (uint32_t *)results, 5));
     SCLogDebug("running tests done");
 
     Host *src = HostLookupHostFromHash(&p[1]->src);
-    if (src) {
-        void *tag = HostGetStorageById(src, host_tag_id);
-        if (tag != NULL) {
-            printf("tag should have been expired: ");
-            result = 0;
-        }
+    FAIL_IF_NULL(src);
+    FAIL_IF_NOT_NULL(HostGetStorageById(src, host_tag_id));
 
-        HostRelease(src);
-    }
     Host *dst = HostLookupHostFromHash(&p[1]->dst);
-    if (dst) {
-        void *tag = HostGetStorageById(dst, host_tag_id);
-        BUG_ON(tag == NULL);
+    FAIL_IF_NULL(dst);
 
-        DetectTagDataEntry *iter = tag;
+    void *tag = HostGetStorageById(dst, host_tag_id);
+    FAIL_IF_NULL(tag);
 
-        /* check internal state */
-        if (!(iter->gid == 1 && iter->sid == 2 && iter->packets == 4 && iter->count == 4)) {
-            printf("gid %u sid %u packets %u count %u: ", iter->gid, iter->sid, iter->packets, iter->count);
-            result = 0;
-        }
+    DetectTagDataEntry *iter = tag;
 
-        HostRelease(dst);
-    }
-    BUG_ON(src == NULL || dst == NULL);
+    /* check internal state */
+    FAIL_IF_NOT(iter->gid == 1);
+    FAIL_IF_NOT(iter->sid == 2);
+    FAIL_IF_NOT(iter->packets == 4);
+    FAIL_IF_NOT(iter->count == 4);
+
+    HostRelease(src);
+    HostRelease(dst);
 
     UTHFreePackets(p, 7);
 
     HostShutdown();
     TagDestroyCtx();
     StorageCleanup();
-    return result;
+    PASS;
 }
 
 /**
@@ -689,7 +683,6 @@ static int DetectTagTestPacket01 (void)
  */
 static int DetectTagTestPacket02 (void)
 {
-    int result = 0;
     uint8_t *buf = (uint8_t *)"Hi all!";
     uint8_t *buf2 = (uint8_t *)"lalala!";
     uint16_t buf_len = strlen((char *)buf);
@@ -707,9 +700,7 @@ static int DetectTagTestPacket02 (void)
     HostInitConfig(1);
 
     DetectEngineCtx *de_ctx = DetectEngineCtxInit();
-    if (de_ctx == NULL) {
-        goto end;
-    }
+    FAIL_IF_NULL(de_ctx);
     de_ctx->flags |= DE_QUIET;
 
     Packet *p[7];
@@ -746,8 +737,7 @@ static int DetectTagTestPacket02 (void)
     uint32_t sid[5] = {1,2,3,4,5};
     int numsigs = 5;
 
-    if (UTHAppendSigs(de_ctx, sigs, numsigs) == 0)
-        goto cleanup;
+    FAIL_IF(UTHAppendSigs(de_ctx, sigs, numsigs) == 0);
 
     //de_ctx->flags |= DE_QUIET;
 
@@ -768,41 +758,26 @@ static int DetectTagTestPacket02 (void)
     int i = 0;
     for (; i < num_packets; i++) {
         SCLogDebug("packet %d", i);
-        TimeGet(&p[i]->ts);
+        p[i]->ts = TimeGet();
         SigMatchSignatures(&th_v, de_ctx, det_ctx, p[i]);
-        if (UTHCheckPacketMatchResults(p[i], sid, (uint32_t *)&results[i][0], numsigs) == 0)
-            goto cleanup;
+        FAIL_IF(UTHCheckPacketMatchResults(p[i], sid, (uint32_t *)&results[i][0], numsigs) == 0);
 
         TimeSetIncrementTime(2);
         SCLogDebug("packet %d flag %s", i, p[i]->flags & PKT_HAS_TAG ? "true" : "false");
 
         /* see if the PKT_HAS_TAG is set on the packet if needed */
-        int expect;
-        if (i == 0 || i == 2 || i == 3 || i == 5 || i == 6)
-            expect = FALSE;
-        else
-            expect = TRUE;
-        if (((p[i]->flags & PKT_HAS_TAG) ? TRUE : FALSE) != expect)
-            goto cleanup;
+        bool expect = (i == 1 || i == 4);
+        FAIL_IF(((p[i]->flags & PKT_HAS_TAG) ? true : false) != expect);
     }
 
-    result = 1;
-
-cleanup:
     UTHFreePackets(p, 7);
-    if (det_ctx != NULL)
-        DetectEngineThreadCtxDeinit(&th_v, (void *)det_ctx);
+    DetectEngineThreadCtxDeinit(&th_v, (void *)det_ctx);
+    DetectEngineCtxFree(de_ctx);
 
-    if (de_ctx != NULL) {
-        SigGroupCleanup(de_ctx);
-        SigCleanSignatures(de_ctx);
-        DetectEngineCtxFree(de_ctx);
-    }
-end:
     HostShutdown();
     TagDestroyCtx();
     StorageCleanup();
-    return result;
+    PASS;
 }
 
 /**
@@ -810,7 +785,6 @@ end:
  */
 static int DetectTagTestPacket03 (void)
 {
-    int result = 0;
     uint8_t *buf = (uint8_t *)"Hi all!";
     uint8_t *buf2 = (uint8_t *)"lalala!";
     uint16_t buf_len = strlen((char *)buf);
@@ -828,9 +802,8 @@ static int DetectTagTestPacket03 (void)
     HostInitConfig(1);
 
     DetectEngineCtx *de_ctx = DetectEngineCtxInit();
-    if (de_ctx == NULL) {
-        goto end;
-    }
+    FAIL_IF_NULL(de_ctx);
+
     de_ctx->flags |= DE_QUIET;
 
     Packet *p[7];
@@ -867,8 +840,7 @@ static int DetectTagTestPacket03 (void)
     uint32_t sid[5] = {1,2,3,4,5};
     int numsigs = 5;
 
-    if (UTHAppendSigs(de_ctx, sigs, numsigs) == 0)
-        goto cleanup;
+    FAIL_IF(UTHAppendSigs(de_ctx, sigs, numsigs) == 0);
 
     int32_t results[7][5] = {
                               {1, 1, 0, 0, 0},
@@ -888,38 +860,23 @@ static int DetectTagTestPacket03 (void)
     for (; i < num_packets; i++) {
         SigMatchSignatures(&th_v, de_ctx, det_ctx, p[i]);
 
-        if (UTHCheckPacketMatchResults(p[i], sid, (uint32_t *)&results[i][0], numsigs) == 0)
-            goto cleanup;
+        FAIL_IF(UTHCheckPacketMatchResults(p[i], sid, (uint32_t *)&results[i][0], numsigs) == 0);
 
         SCLogDebug("packet %d flag %s", i, p[i]->flags & PKT_HAS_TAG ? "true" : "false");
 
         /* see if the PKT_HAS_TAG is set on the packet if needed */
-        int expect;
-        if (i == 0 || i == 3 || i == 5 || i == 6)
-            expect = FALSE;
-        else
-            expect = TRUE;
-        if (((p[i]->flags & PKT_HAS_TAG) ? TRUE : FALSE) != expect)
-            goto cleanup;
+        bool expect = (i == 1 || i == 2 || i == 4);
+        FAIL_IF(((p[i]->flags & PKT_HAS_TAG) ? true : false) != expect);
     }
 
-    result = 1;
-
-cleanup:
     UTHFreePackets(p, 7);
-    if (det_ctx != NULL)
-        DetectEngineThreadCtxDeinit(&th_v, (void *)det_ctx);
+    DetectEngineThreadCtxDeinit(&th_v, (void *)det_ctx);
+    DetectEngineCtxFree(de_ctx);
 
-    if (de_ctx != NULL) {
-        SigGroupCleanup(de_ctx);
-        SigCleanSignatures(de_ctx);
-        DetectEngineCtxFree(de_ctx);
-    }
-end:
     HostShutdown();
     TagDestroyCtx();
     StorageCleanup();
-    return result;
+    PASS;
 }
 
 /**
@@ -927,7 +884,6 @@ end:
  */
 static int DetectTagTestPacket04 (void)
 {
-    int result = 0;
     uint8_t *buf = (uint8_t *)"Hi all!";
     uint8_t *buf2 = (uint8_t *)"lalala!";
     uint16_t buf_len = strlen((char *)buf);
@@ -946,14 +902,12 @@ static int DetectTagTestPacket04 (void)
     FlowInitConfig(1);
 
     f = FlowAlloc();
-    BUG_ON(f == NULL);
+    FAIL_IF_NULL(f);
     FLOW_INITIALIZE(f);
     f->protoctx = (void *)&ssn;
     f->flags |= FLOW_IPV4;
-    if (inet_pton(AF_INET, "192.168.1.5", f->src.addr_data32) != 1)
-        goto end;
-    if (inet_pton(AF_INET, "192.168.1.1", f->dst.addr_data32) != 1)
-        goto end;
+    FAIL_IF(inet_pton(AF_INET, "192.168.1.5", f->src.addr_data32) != 1);
+    FAIL_IF(inet_pton(AF_INET, "192.168.1.1", f->dst.addr_data32) != 1);
 
     DecodeThreadVars dtv;
     ThreadVars th_v;
@@ -962,9 +916,7 @@ static int DetectTagTestPacket04 (void)
     memset(&th_v, 0, sizeof(th_v));
 
     DetectEngineCtx *de_ctx = DetectEngineCtxInit();
-    if (de_ctx == NULL) {
-        goto end;
-    }
+    FAIL_IF_NULL(de_ctx);
     de_ctx->flags |= DE_QUIET;
 
     Packet *p[7];
@@ -1001,8 +953,7 @@ static int DetectTagTestPacket04 (void)
     uint32_t sid[5] = {1,2,3,4,5};
     int numsigs = 5;
 
-    if (UTHAppendSigs(de_ctx, sigs, numsigs) == 0)
-        goto cleanup;
+    FAIL_IF(UTHAppendSigs(de_ctx, sigs, numsigs) == 0);
 
     int32_t results[7][5] = {
                               {1, 0, 0, 0, 0},
@@ -1024,44 +975,29 @@ static int DetectTagTestPacket04 (void)
         p[i]->flow->protoctx = &ssn;
         SigMatchSignatures(&th_v, de_ctx, det_ctx, p[i]);
 
-        if (UTHCheckPacketMatchResults(p[i], sid, (uint32_t *)&results[i][0], numsigs) == 0)
-            goto cleanup;
+        FAIL_IF(UTHCheckPacketMatchResults(p[i], sid, (uint32_t *)&results[i][0], numsigs) == 0);
 
         SCLogDebug("packet %d flag %s", i, p[i]->flags & PKT_HAS_TAG ? "true" : "false");
         /* see if the PKT_HAS_TAG is set on the packet if needed */
-        int expect;
-        if (i == 0 || i == 4 || i == 5 || i == 6)
-            expect = FALSE;
-        else
-            expect = TRUE;
-        if (((p[i]->flags & PKT_HAS_TAG) ? TRUE : FALSE) != expect)
-            goto cleanup;
+        bool expect = (i == 1 || i == 2 || i == 3);
+        FAIL_IF(((p[i]->flags & PKT_HAS_TAG) ? true : false) != expect);
     }
 
-    result = 1;
-
-cleanup:
     UTHFreePackets(p, 7);
-    if (det_ctx != NULL)
-        DetectEngineThreadCtxDeinit(&th_v, (void *)det_ctx);
-
-    if (de_ctx != NULL) {
-        SigGroupCleanup(de_ctx);
-        SigCleanSignatures(de_ctx);
-        DetectEngineCtxFree(de_ctx);
-    }
+    DetectEngineThreadCtxDeinit(&th_v, (void *)det_ctx);
+    DetectEngineCtxFree(de_ctx);
 
     /* clean up flow */
     uint8_t proto_map = FlowGetProtoMapping(f->proto);
     FlowClearMemory(f, proto_map);
     FLOW_DESTROY(f);
     FlowFree(f);
-end:
+
     FlowShutdown();
     HostShutdown();
     TagDestroyCtx();
     StorageCleanup();
-    return result;
+    PASS;
 }
 
 /**
@@ -1069,7 +1005,6 @@ end:
  */
 static int DetectTagTestPacket05 (void)
 {
-    int result = 0;
     uint8_t *buf = (uint8_t *)"Hi all!";
     uint8_t *buf2 = (uint8_t *)"lalala!";
     uint16_t buf_len = strlen((char *)buf);
@@ -1088,14 +1023,12 @@ static int DetectTagTestPacket05 (void)
     FlowInitConfig(1);
 
     f = FlowAlloc();
-    BUG_ON(f == NULL);
+    FAIL_IF_NULL(f);
     FLOW_INITIALIZE(f);
     f->protoctx = (void *)&ssn;
     f->flags |= FLOW_IPV4;
-    if (inet_pton(AF_INET, "192.168.1.5", f->src.addr_data32) != 1)
-        goto end;
-    if (inet_pton(AF_INET, "192.168.1.1", f->dst.addr_data32) != 1)
-        goto end;
+    FAIL_IF(inet_pton(AF_INET, "192.168.1.5", f->src.addr_data32) != 1);
+    FAIL_IF(inet_pton(AF_INET, "192.168.1.1", f->dst.addr_data32) != 1);
 
     DecodeThreadVars dtv;
     ThreadVars th_v;
@@ -1104,9 +1037,7 @@ static int DetectTagTestPacket05 (void)
     memset(&th_v, 0, sizeof(th_v));
 
     DetectEngineCtx *de_ctx = DetectEngineCtxInit();
-    if (de_ctx == NULL) {
-        goto end;
-    }
+    FAIL_IF_NULL(de_ctx);
     de_ctx->flags |= DE_QUIET;
 
     Packet *p[7];
@@ -1143,8 +1074,7 @@ static int DetectTagTestPacket05 (void)
     uint32_t sid[5] = {1,2,3,4,5};
     int numsigs = 5;
 
-    if (UTHAppendSigs(de_ctx, sigs, numsigs) == 0)
-        goto cleanup;
+    FAIL_IF(UTHAppendSigs(de_ctx, sigs, numsigs) == 0);
 
     int32_t results[7][5] = {
                               {1, 0, 0, 0, 0},
@@ -1166,49 +1096,34 @@ static int DetectTagTestPacket05 (void)
         p[i]->flow->protoctx = &ssn;
 
         SCLogDebug("packet %d", i);
-        TimeGet(&p[i]->ts);
+        p[i]->ts = TimeGet();
         SigMatchSignatures(&th_v, de_ctx, det_ctx, p[i]);
 
-        if (UTHCheckPacketMatchResults(p[i], sid, (uint32_t *)&results[i][0], numsigs) == 0)
-            goto cleanup;
+        FAIL_IF(UTHCheckPacketMatchResults(p[i], sid, (uint32_t *)&results[i][0], numsigs) == 0);
 
         TimeSetIncrementTime(2);
 
         SCLogDebug("packet %d flag %s", i, p[i]->flags & PKT_HAS_TAG ? "true" : "false");
         /* see if the PKT_HAS_TAG is set on the packet if needed */
-        int expect;
-        if (i == 0 || i == 5 || i == 6)
-            expect = FALSE;
-        else
-            expect = TRUE;
-        if (((p[i]->flags & PKT_HAS_TAG) ? TRUE : FALSE) != expect)
-            goto cleanup;
+        bool expect = (i == 1 || i == 2 || i == 3 || i == 4);
+        FAIL_IF(((p[i]->flags & PKT_HAS_TAG) ? true : false) != expect);
     }
 
-    result = 1;
-
-cleanup:
     UTHFreePackets(p, 7);
-    if (det_ctx != NULL)
-        DetectEngineThreadCtxDeinit(&th_v, (void *)det_ctx);
-
-    if (de_ctx != NULL) {
-        SigGroupCleanup(de_ctx);
-        SigCleanSignatures(de_ctx);
-        DetectEngineCtxFree(de_ctx);
-    }
+    DetectEngineThreadCtxDeinit(&th_v, (void *)det_ctx);
+    DetectEngineCtxFree(de_ctx);
 
     /* clean up flow */
     uint8_t proto_map = FlowGetProtoMapping(f->proto);
     FlowClearMemory(f, proto_map);
     FLOW_DESTROY(f);
     FlowFree(f);
-end:
+
     FlowShutdown();
     HostShutdown();
     TagDestroyCtx();
     StorageCleanup();
-    return result;
+    PASS;
 }
 
 /**
@@ -1216,7 +1131,6 @@ end:
  */
 static int DetectTagTestPacket06 (void)
 {
-    int result = 0;
     uint8_t *buf = (uint8_t *)"Hi all!";
     uint8_t *buf2 = (uint8_t *)"lalala!";
     uint16_t buf_len = strlen((char *)buf);
@@ -1235,14 +1149,12 @@ static int DetectTagTestPacket06 (void)
     FlowInitConfig(1);
 
     f = FlowAlloc();
-    BUG_ON(f == NULL);
+    FAIL_IF_NULL(f);
     FLOW_INITIALIZE(f);
     f->protoctx = (void *)&ssn;
     f->flags |= FLOW_IPV4;
-    if (inet_pton(AF_INET, "192.168.1.5", f->src.addr_data32) != 1)
-        goto end;
-    if (inet_pton(AF_INET, "192.168.1.1", f->dst.addr_data32) != 1)
-        goto end;
+    FAIL_IF(inet_pton(AF_INET, "192.168.1.5", f->src.addr_data32) != 1);
+    FAIL_IF(inet_pton(AF_INET, "192.168.1.1", f->dst.addr_data32) != 1);
 
     DecodeThreadVars dtv;
     ThreadVars th_v;
@@ -1251,9 +1163,7 @@ static int DetectTagTestPacket06 (void)
     memset(&th_v, 0, sizeof(th_v));
 
     DetectEngineCtx *de_ctx = DetectEngineCtxInit();
-    if (de_ctx == NULL) {
-        goto end;
-    }
+    FAIL_IF_NULL(de_ctx);
     de_ctx->flags |= DE_QUIET;
 
     Packet *p[7];
@@ -1290,8 +1200,7 @@ static int DetectTagTestPacket06 (void)
     uint32_t sid[5] = {1,2,3,4,5};
     int numsigs = 5;
 
-    if (UTHAppendSigs(de_ctx, sigs, numsigs) == 0)
-        goto cleanup;
+    FAIL_IF(UTHAppendSigs(de_ctx, sigs, numsigs) == 0);
 
     int32_t results[7][5] = {
                               {1, 0, 0, 0, 0},
@@ -1313,45 +1222,30 @@ static int DetectTagTestPacket06 (void)
         p[i]->flow->protoctx = &ssn;
         SigMatchSignatures(&th_v, de_ctx, det_ctx, p[i]);
 
-        if (UTHCheckPacketMatchResults(p[i], sid, (uint32_t *)&results[i][0], numsigs) == 0)
-            goto cleanup;
+        FAIL_IF(UTHCheckPacketMatchResults(p[i], sid, (uint32_t *)&results[i][0], numsigs) == 0);
 
         SCLogDebug("packet %d flag %s", i, p[i]->flags & PKT_HAS_TAG ? "true" : "false");
 
         /* see if the PKT_HAS_TAG is set on the packet if needed */
-        int expect;
-        if (i == 0 || i == 3 || i == 4 || i == 5 || i == 6)
-            expect = FALSE;
-        else
-            expect = TRUE;
-        if (((p[i]->flags & PKT_HAS_TAG) ? TRUE : FALSE) != expect)
-            goto cleanup;
+        bool expect = (i == 1 || i == 2);
+        FAIL_IF(((p[i]->flags & PKT_HAS_TAG) ? true : false) != expect);
     }
 
-    result = 1;
-
-cleanup:
     UTHFreePackets(p, 7);
-    if (det_ctx != NULL)
-        DetectEngineThreadCtxDeinit(&th_v, (void *)det_ctx);
-
-    if (de_ctx != NULL) {
-        SigGroupCleanup(de_ctx);
-        SigCleanSignatures(de_ctx);
-        DetectEngineCtxFree(de_ctx);
-    }
+    DetectEngineThreadCtxDeinit(&th_v, (void *)det_ctx);
+    DetectEngineCtxFree(de_ctx);
 
     /* clean up flow */
     uint8_t proto_map = FlowGetProtoMapping(f->proto);
     FlowClearMemory(f, proto_map);
     FLOW_DESTROY(f);
     FlowFree(f);
-end:
+
     FlowShutdown();
     HostShutdown();
     TagDestroyCtx();
     StorageCleanup();
-    return result;
+    PASS;
 }
 
 /**
@@ -1359,7 +1253,6 @@ end:
  */
 static int DetectTagTestPacket07 (void)
 {
-    int result = 0;
     uint8_t *buf = (uint8_t *)"Hi all!";
     uint8_t *buf2 = (uint8_t *)"lalala!";
     uint16_t buf_len = strlen((char *)buf);
@@ -1378,14 +1271,12 @@ static int DetectTagTestPacket07 (void)
     FlowInitConfig(1);
 
     f = FlowAlloc();
-    BUG_ON(f == NULL);
+    FAIL_IF_NULL(f);
     FLOW_INITIALIZE(f);
     f->protoctx = (void *)&ssn;
     f->flags |= FLOW_IPV4;
-    if (inet_pton(AF_INET, "192.168.1.5", f->src.addr_data32) != 1)
-        goto end;
-    if (inet_pton(AF_INET, "192.168.1.1", f->dst.addr_data32) != 1)
-        goto end;
+    FAIL_IF(inet_pton(AF_INET, "192.168.1.5", f->src.addr_data32) != 1);
+    FAIL_IF(inet_pton(AF_INET, "192.168.1.1", f->dst.addr_data32) != 1);
 
     DecodeThreadVars dtv;
     ThreadVars th_v;
@@ -1394,9 +1285,7 @@ static int DetectTagTestPacket07 (void)
     memset(&th_v, 0, sizeof(th_v));
 
     DetectEngineCtx *de_ctx = DetectEngineCtxInit();
-    if (de_ctx == NULL) {
-        goto end;
-    }
+    FAIL_IF_NULL(de_ctx);
     de_ctx->flags |= DE_QUIET;
 
     Packet *p[7];
@@ -1433,9 +1322,7 @@ static int DetectTagTestPacket07 (void)
     uint32_t sid[5] = {1,2,3,4,5};
     int numsigs = 5;
 
-    if (UTHAppendSigs(de_ctx, sigs, numsigs) == 0)
-        goto cleanup;
-
+    FAIL_IF(UTHAppendSigs(de_ctx, sigs, numsigs) == 0);
     int32_t results[7][5] = {
                               {1, 0, 0, 0, 0},
                               {0, 0, 0, 0, 0},
@@ -1456,46 +1343,30 @@ static int DetectTagTestPacket07 (void)
         p[i]->flow->protoctx = &ssn;
         SigMatchSignatures(&th_v, de_ctx, det_ctx, p[i]);
 
-        if (UTHCheckPacketMatchResults(p[i], sid, (uint32_t *)&results[i][0], numsigs) == 0)
-            goto cleanup;
+        FAIL_IF(UTHCheckPacketMatchResults(p[i], sid, (uint32_t *)&results[i][0], numsigs) == 0);
 
         SCLogDebug("packet %d flag %s", i, p[i]->flags & PKT_HAS_TAG ? "true" : "false");
-#if 1
+
         /* see if the PKT_HAS_TAG is set on the packet if needed */
-        int expect;
-        if (i == 0 || i == 6)
-            expect = FALSE;
-        else
-            expect = TRUE;
-        if (((p[i]->flags & PKT_HAS_TAG) ? TRUE : FALSE) != expect)
-            goto cleanup;
-#endif
+        bool expect = (i == 1 || i == 2 || i == 3 || i == 4 || i == 5);
+        FAIL_IF(((p[i]->flags & PKT_HAS_TAG) ? true : false) != expect);
     }
 
-    result = 1;
-
-cleanup:
     UTHFreePackets(p, 7);
-    if (det_ctx != NULL)
-        DetectEngineThreadCtxDeinit(&th_v, (void *)det_ctx);
-
-    if (de_ctx != NULL) {
-        SigGroupCleanup(de_ctx);
-        SigCleanSignatures(de_ctx);
-        DetectEngineCtxFree(de_ctx);
-    }
+    DetectEngineThreadCtxDeinit(&th_v, (void *)det_ctx);
+    DetectEngineCtxFree(de_ctx);
 
     /* clean up flow */
     uint8_t proto_map = FlowGetProtoMapping(f->proto);
     FlowClearMemory(f, proto_map);
     FLOW_DESTROY(f);
     FlowFree(f);
-end:
+
     FlowShutdown();
     HostShutdown();
     TagDestroyCtx();
     StorageCleanup();
-    return result;
+    PASS;
 }
 
 #endif /* UNITTESTS */
