@@ -26,9 +26,6 @@
 #ifndef __DETECT_GID_H__
 #define __DETECT_GID_H__
 
-#include "decode-events.h"
-#include "decode-ipv4.h"
-#include "decode-tcp.h"
 
 /**
  * Registration function for gid: keyword
