@@ -26,7 +26,7 @@
 
 void DetectHttpHeaderRegister(void);
 void DetectHttpRawHeaderRegister(void);
-
-void DetectEngineCleanHHDBuffers(DetectEngineThreadCtx *det_ctx);
+void DetectHttpRequestHeaderRegister(void);
+void DetectHttpResponseHeaderRegister(void);
 
 #endif /* __DETECT_HTTP_HEADER_H__ */
