@@ -794,7 +794,7 @@ static int DetectLuaSetupPrime(DetectEngineCtx *de_ctx, DetectLuaData *ld, const
                         goto error;
                     }
 
-                    uint32_t idx = VarNameStoreSetupAdd((char *)value, VAR_TYPE_FLOW_VAR);
+                    uint32_t idx = VarNameStoreRegister(value, VAR_TYPE_FLOW_VAR);
                     ld->flowvar[ld->flowvars++] = idx;
                     SCLogDebug("script uses flowvar %u with script id %u", idx, ld->flowvars - 1);
                 }
@@ -816,7 +816,7 @@ static int DetectLuaSetupPrime(DetectEngineCtx *de_ctx, DetectLuaData *ld, const
                         goto error;
                     }
 
-                    uint32_t idx = VarNameStoreSetupAdd((char *)value, VAR_TYPE_FLOW_INT);
+                    uint32_t idx = VarNameStoreRegister(value, VAR_TYPE_FLOW_INT);
                     ld->flowint[ld->flowints++] = idx;
                     SCLogDebug("script uses flowint %u with script id %u", idx, ld->flowints - 1);
                 }
@@ -1166,6 +1166,13 @@ static void DetectLuaFree(DetectEngineCtx *de_ctx, void *ptr)
         if (lua->filename)
             SCFree(lua->filename);
 
+        for (uint16_t i = 0; i < lua->flowints; i++) {
+            VarNameStoreUnregister(lua->flowint[i], VAR_TYPE_FLOW_INT);
+        }
+        for (uint16_t i = 0; i < lua->flowvars; i++) {
+            VarNameStoreUnregister(lua->flowvar[i], VAR_TYPE_FLOW_VAR);
+        }
+
         DetectUnregisterThreadCtxFuncs(de_ctx, lua, "lua");
 
         SCFree(lua);
@@ -1281,7 +1288,10 @@ static int LuaMatchTest01(void)
 
     FAIL_IF_NOT(PacketAlertCheck(p2, 1));
 
-    FlowVar *fv = FlowVarGet(&f, 1);
+    uint32_t id = VarNameStoreLookupByName("cnt", VAR_TYPE_FLOW_VAR);
+    FAIL_IF(id == 0);
+
+    FlowVar *fv = FlowVarGet(&f, id);
     FAIL_IF_NULL(fv);
 
     FAIL_IF(fv->data.fv_str.value_len != 1);
@@ -1398,7 +1408,10 @@ static int LuaMatchTest01a(void)
 
     FAIL_IF_NOT(PacketAlertCheck(p2, 1));
 
-    FlowVar *fv = FlowVarGet(&f, 1);
+    uint32_t id = VarNameStoreLookupByName("cnt", VAR_TYPE_FLOW_VAR);
+    FAIL_IF(id == 0);
+
+    FlowVar *fv = FlowVarGet(&f, id);
     FAIL_IF_NULL(fv);
 
     FAIL_IF(fv->data.fv_str.value_len != 1);
@@ -1503,7 +1516,10 @@ static int LuaMatchTest02(void)
 
     FAIL_IF_NOT(PacketAlertCheck(p2, 1));
 
-    FlowVar *fv = FlowVarGet(&f, 1);
+    uint32_t id = VarNameStoreLookupByName("cnt", VAR_TYPE_FLOW_VAR);
+    FAIL_IF(id == 0);
+
+    FlowVar *fv = FlowVarGet(&f, id);
     FAIL_IF_NULL(fv);
 
     FAIL_IF(fv->data.fv_str.value_len != 1);
@@ -1606,7 +1622,10 @@ static int LuaMatchTest02a(void)
 
     FAIL_IF_NOT(PacketAlertCheck(p2, 1));
 
-    FlowVar *fv = FlowVarGet(&f, 1);
+    uint32_t id = VarNameStoreLookupByName("cnt", VAR_TYPE_FLOW_VAR);
+    FAIL_IF(id == 0);
+
+    FlowVar *fv = FlowVarGet(&f, id);
     FAIL_IF_NULL(fv);
 
     FAIL_IF(fv->data.fv_str.value_len != 1);
@@ -1709,7 +1728,10 @@ static int LuaMatchTest03(void)
 
     FAIL_IF_NOT(PacketAlertCheck(p2, 1));
 
-    FlowVar *fv = FlowVarGet(&f, 1);
+    uint32_t id = VarNameStoreLookupByName("cnt", VAR_TYPE_FLOW_VAR);
+    FAIL_IF(id == 0);
+
+    FlowVar *fv = FlowVarGet(&f, id);
     FAIL_IF_NULL(fv);
 
     FAIL_IF(fv->data.fv_str.value_len != 1);
@@ -1811,7 +1833,10 @@ static int LuaMatchTest03a(void)
     SigMatchSignatures(&th_v, de_ctx, det_ctx, p2);
     FAIL_IF_NOT(PacketAlertCheck(p2, 1));
 
-    FlowVar *fv = FlowVarGet(&f, 1);
+    uint32_t id = VarNameStoreLookupByName("cnt", VAR_TYPE_FLOW_VAR);
+    FAIL_IF(id == 0);
+
+    FlowVar *fv = FlowVarGet(&f, id);
     FAIL_IF_NULL(fv);
 
     FAIL_IF(fv->data.fv_str.value_len != 1);
@@ -1925,7 +1950,10 @@ static int LuaMatchTest04(void)
 
     FAIL_IF_NOT(PacketAlertCheck(p2, 1));
 
-    FlowVar *fv = FlowVarGet(&f, 1);
+    uint32_t id = VarNameStoreLookupByName("cnt", VAR_TYPE_FLOW_INT);
+    FAIL_IF(id == 0);
+
+    FlowVar *fv = FlowVarGet(&f, id);
     FAIL_IF_NULL(fv);
 
     FAIL_IF(fv->data.fv_int.value != 2);
@@ -2040,7 +2068,10 @@ static int LuaMatchTest04a(void)
 
     FAIL_IF_NOT(PacketAlertCheck(p2, 1));
 
-    FlowVar *fv = FlowVarGet(&f, 1);
+    uint32_t id = VarNameStoreLookupByName("cnt", VAR_TYPE_FLOW_INT);
+    FAIL_IF(id == 0);
+
+    FlowVar *fv = FlowVarGet(&f, id);
     FAIL_IF_NULL(fv);
 
     FAIL_IF(fv->data.fv_int.value != 2);
@@ -2148,7 +2179,10 @@ static int LuaMatchTest05(void)
 
     FAIL_IF_NOT(PacketAlertCheck(p2, 1));
 
-    FlowVar *fv = FlowVarGet(&f, 1);
+    uint32_t id = VarNameStoreLookupByName("cnt", VAR_TYPE_FLOW_INT);
+    FAIL_IF(id == 0);
+
+    FlowVar *fv = FlowVarGet(&f, id);
     FAIL_IF_NULL(fv);
 
     FAIL_IF(fv->data.fv_int.value != 2);
@@ -2256,7 +2290,10 @@ static int LuaMatchTest05a(void)
 
     FAIL_IF_NOT(PacketAlertCheck(p2, 1));
 
-    FlowVar *fv = FlowVarGet(&f, 1);
+    uint32_t id = VarNameStoreLookupByName("cnt", VAR_TYPE_FLOW_INT);
+    FAIL_IF(id == 0);
+
+    FlowVar *fv = FlowVarGet(&f, id);
     FAIL_IF_NULL(fv);
 
     FAIL_IF(fv->data.fv_int.value != 2);
@@ -2369,7 +2406,10 @@ static int LuaMatchTest06(void)
 
     FAIL_IF_NOT(PacketAlertCheck(p2, 1));
 
-    FlowVar *fv = FlowVarGet(&f, 1);
+    uint32_t id = VarNameStoreLookupByName("cnt", VAR_TYPE_FLOW_INT);
+    FAIL_IF(id == 0);
+
+    FlowVar *fv = FlowVarGet(&f, id);
     FAIL_IF_NULL(fv);
 
     FAIL_IF(fv->data.fv_int.value != 0);
@@ -2482,7 +2522,10 @@ static int LuaMatchTest06a(void)
 
     FAIL_IF_NOT(PacketAlertCheck(p2, 1));
 
-    FlowVar *fv = FlowVarGet(&f, 1);
+    uint32_t id = VarNameStoreLookupByName("cnt", VAR_TYPE_FLOW_INT);
+    FAIL_IF(id == 0);
+
+    FlowVar *fv = FlowVarGet(&f, id);
     FAIL_IF_NULL(fv);
 
     FAIL_IF(fv->data.fv_int.value != 0);
