@@ -1,4 +1,4 @@
-/* Copyright (C) 2007-2013 Open Information Security Foundation
+/* Copyright (C) 2007-2022 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -21,11 +21,13 @@
  * \author Victor Julien <victor@inliniac.net>
  */
 
-#ifndef __DETECT_LUAJIT_H__
-#define __DETECT_LUAJIT_H__
+#ifndef __DETECT_LUA_H__
+#define __DETECT_LUA_H__
 
 #ifdef HAVE_LUA
 
+#include "util-lua.h"
+
 typedef struct DetectLuaThreadData {
     lua_State *luastate;
     uint32_t flags;
@@ -34,6 +36,7 @@ typedef struct DetectLuaThreadData {
 
 #define DETECT_LUAJIT_MAX_FLOWVARS  15
 #define DETECT_LUAJIT_MAX_FLOWINTS  15
+#define DETECT_LUAJIT_MAX_BYTEVARS  15
 
 typedef struct DetectLuaData {
     int thread_ctx_id;
@@ -46,6 +49,8 @@ typedef struct DetectLuaData {
     uint16_t flowints;
     uint16_t flowvars;
     uint32_t flowvar[DETECT_LUAJIT_MAX_FLOWVARS];
+    uint16_t bytevars;
+    uint32_t bytevar[DETECT_LUAJIT_MAX_BYTEVARS];
     uint32_t sid;
     uint32_t rev;
     uint32_t gid;
@@ -62,4 +67,4 @@ int DetectLuaMatchBuffer(DetectEngineThreadCtx *det_ctx,
 
 void DetectLuaPostSetup(Signature *s);
 
-#endif /* __DETECT_FILELUAJIT_H__ */
+#endif /* __DETECT_LUA_H__ */
