@@ -28,8 +28,6 @@
 #ifndef __DETECT_MARK_H__
 #define __DETECT_MARK_H__
 
-#include "decode.h"
-#include "detect.h"
 
 /**
  * \struct DetectMarkData_
