@@ -27,13 +27,12 @@
  * also specify the version, something like
  * ssh.softwareversion:"PuTTY-Release-0.55"
  * I find this useful to match over a known vulnerable server/client
- * software version incombination to other checks, so you can know
+ * software version in combination to other checks, so you can know
  * that the risk is higher
  */
 
 #include "suricata-common.h"
 #include "threads.h"
-#include "debug.h"
 #include "decode.h"
 
 #include "detect.h"
@@ -42,6 +41,7 @@
 #include "detect-engine.h"
 #include "detect-engine-mpm.h"
 #include "detect-engine-state.h"
+#include "detect-engine-build.h"
 
 #include "flow.h"
 #include "flow-var.h"
@@ -76,15 +76,6 @@ static void DetectSshSoftwareVersionRegisterTests(void);
 static void DetectSshSoftwareVersionFree(DetectEngineCtx *de_ctx, void *);
 static int g_ssh_banner_list_id = 0;
 
-static int InspectSshBanner(ThreadVars *tv,
-        DetectEngineCtx *de_ctx, DetectEngineThreadCtx *det_ctx,
-        const Signature *s, const SigMatchData *smd,
-        Flow *f, uint8_t flags, void *alstate,
-        void *txv, uint64_t tx_id)
-{
-    return DetectEngineInspectGenericList(tv, de_ctx, det_ctx, s, smd,
-                                          f, flags, alstate, txv, tx_id);
-}
 
 /**
  * \brief Registration function for keyword: ssh.softwareversion
@@ -107,12 +98,10 @@ void DetectSshSoftwareVersionRegister(void)
 
     g_ssh_banner_list_id = DetectBufferTypeRegister("ssh_banner");
 
-    DetectAppLayerInspectEngineRegister("ssh_banner",
-            ALPROTO_SSH, SIG_FLAG_TOSERVER, SshStateBannerDone,
-            InspectSshBanner);
-    DetectAppLayerInspectEngineRegister("ssh_banner",
-            ALPROTO_SSH, SIG_FLAG_TOCLIENT, SshStateBannerDone,
-            InspectSshBanner);
+    DetectAppLayerInspectEngineRegister2("ssh_banner", ALPROTO_SSH, SIG_FLAG_TOSERVER,
+            SshStateBannerDone, DetectEngineInspectGenericList, NULL);
+    DetectAppLayerInspectEngineRegister2("ssh_banner", ALPROTO_SSH, SIG_FLAG_TOCLIENT,
+            SshStateBannerDone, DetectEngineInspectGenericList, NULL);
 }
 
 /**
@@ -167,43 +156,50 @@ static int DetectSshSoftwareVersionMatch (DetectEngineThreadCtx *det_ctx,
 static DetectSshSoftwareVersionData *DetectSshSoftwareVersionParse (DetectEngineCtx *de_ctx, const char *str)
 {
     DetectSshSoftwareVersionData *ssh = NULL;
-    int ret = 0, res = 0;
-    int ov[MAX_SUBSTRINGS];
+    int res = 0;
+    size_t pcre2_len;
 
-    ret = DetectParsePcreExec(&parse_regex, str, 0, 0, ov, MAX_SUBSTRINGS);
+    pcre2_match_data *match = NULL;
+    int ret = DetectParsePcreExec(&parse_regex, &match, str, 0, 0);
 
     if (ret < 1 || ret > 3) {
-        SCLogError(SC_ERR_PCRE_MATCH, "invalid ssh.softwareversion option");
+        SCLogError("invalid ssh.softwareversion option");
         goto error;
     }
 
     if (ret > 1) {
         const char *str_ptr = NULL;
-        res = pcre_get_substring((char *)str, ov, MAX_SUBSTRINGS, 1, &str_ptr);
+        res = pcre2_substring_get_bynumber(match, 1, (PCRE2_UCHAR8 **)&str_ptr, &pcre2_len);
         if (res < 0) {
-            SCLogError(SC_ERR_PCRE_GET_SUBSTRING, "pcre_get_substring failed");
+            SCLogError("pcre2_substring_get_bynumber failed");
             goto error;
         }
 
         /* We have a correct id option */
         ssh = SCMalloc(sizeof(DetectSshSoftwareVersionData));
-        if (unlikely(ssh == NULL))
-            goto error;
-
-        ssh->software_ver = (uint8_t *)SCStrdup((char *)str_ptr);
-        if (ssh->software_ver == NULL) {
+        if (unlikely(ssh == NULL)) {
+            pcre2_substring_free((PCRE2_UCHAR *)str_ptr);
             goto error;
         }
-        pcre_free_substring(str_ptr);
+        ssh->software_ver = (uint8_t *)SCStrdup((char *)str_ptr);
+        if (ssh->software_ver == NULL) {
+            pcre2_substring_free((PCRE2_UCHAR *)str_ptr);
+            goto error;
+        }
+        pcre2_substring_free((PCRE2_UCHAR *)str_ptr);
 
-        ssh->len = strlen((char *)ssh->software_ver);
+        ssh->len = (uint16_t)strlen((char *)ssh->software_ver);
 
         SCLogDebug("will look for ssh %s", ssh->software_ver);
     }
 
+    pcre2_match_data_free(match);
     return ssh;
 
 error:
+    if (match) {
+        pcre2_match_data_free(match);
+    }
     if (ssh != NULL)
         DetectSshSoftwareVersionFree(de_ctx, ssh);
     return NULL;
@@ -271,6 +267,7 @@ static void DetectSshSoftwareVersionFree(DetectEngineCtx *de_ctx, void *ptr)
 }
 
 #ifdef UNITTESTS /* UNITTESTS */
+#include "detect-engine-alert.h"
 
 /**
  * \test DetectSshSoftwareVersionTestParse01 is a test to make sure that we parse
@@ -573,4 +570,4 @@ static void DetectSshSoftwareVersionRegisterTests(void)
     UtRegisterTest("DetectSshSoftwareVersionTestDetect03",
                    DetectSshSoftwareVersionTestDetect03);
 }
-#endif /* UNITTESTS */
\ No newline at end of file
+#endif /* UNITTESTS */
