@@ -28,10 +28,13 @@
 #include "detect.h"
 #include "detect-engine.h"
 #include "detect-parse.h"
-#include "detect-pcre.h"
 #include "detect-transform-pcrexform.h"
+#include "detect-pcre.h"
 
-typedef DetectParseRegex DetectTransformPcrexformData;
+typedef struct DetectTransformPcrexformData {
+    pcre2_code *regex;
+    pcre2_match_context *context;
+} DetectTransformPcrexformData;
 
 static int DetectTransformPcrexformSetup (DetectEngineCtx *, Signature *, const char *);
 static void DetectTransformPcrexformFree(DetectEngineCtx *, void *);
@@ -62,9 +65,12 @@ static void DetectTransformPcrexformFree(DetectEngineCtx *de_ctx, void *ptr)
 {
     if (ptr != NULL) {
         DetectTransformPcrexformData *pxd = (DetectTransformPcrexformData *) ptr;
+        pcre2_match_context_free(pxd->context);
+        pcre2_code_free(pxd->regex);
         SCFree(pxd);
     }
 }
+
 /**
  *  \internal
  *  \brief Apply the pcrexform keyword to the last pattern match
@@ -79,29 +85,48 @@ static int DetectTransformPcrexformSetup (DetectEngineCtx *de_ctx, Signature *s,
     SCEnter();
 
     // Create pxd from regexstr
-    DetectTransformPcrexformData *pxd = SCCalloc(sizeof(*pxd), 1);
+    DetectTransformPcrexformData *pxd = SCCalloc(1, sizeof(*pxd));
     if (pxd == NULL) {
         SCLogDebug("pxd allocation failed");
         SCReturnInt(-1);
     }
 
-    if (!DetectSetupParseRegexesOpts(regexstr, pxd, 0)) {
+    pxd->context = pcre2_match_context_create(NULL);
+    if (pxd->context == NULL) {
         SCFree(pxd);
         SCReturnInt(-1);
     }
-
-    if (pxd->study != NULL) {
-        pxd->study->match_limit = SC_MATCH_LIMIT_DEFAULT;
-        pxd->study->flags |= PCRE_EXTRA_MATCH_LIMIT;
-#ifndef NO_PCRE_MATCH_RLIMIT
-        pxd->study->match_limit_recursion = SC_MATCH_LIMIT_RECURSION_DEFAULT;
-        pxd->study->flags |= PCRE_EXTRA_MATCH_LIMIT_RECURSION;
-#endif
+    pcre2_set_match_limit(pxd->context, SC_MATCH_LIMIT_DEFAULT);
+    pcre2_set_recursion_limit(pxd->context, SC_MATCH_LIMIT_RECURSION_DEFAULT);
+    int en;
+    PCRE2_SIZE eo;
+    pxd->regex = pcre2_compile((PCRE2_SPTR8)regexstr, PCRE2_ZERO_TERMINATED, 0, &en, &eo, NULL);
+    if (pxd->regex == NULL) {
+        PCRE2_UCHAR buffer[256];
+        pcre2_get_error_message(en, buffer, sizeof(buffer));
+        SCLogError("pcre2 compile of \"%s\" failed at "
+                   "offset %d: %s",
+                regexstr, (int)eo, buffer);
+        pcre2_match_context_free(pxd->context);
+        SCFree(pxd);
+        SCReturnInt(-1);
+    }
+    // check pcd->regex has exactly one capture expression
+    uint32_t nb;
+    if (pcre2_pattern_info(pxd->regex, PCRE2_INFO_CAPTURECOUNT, &nb) < 0) {
+        SCLogError("pcrexform failed getting info about capturecount");
+        DetectTransformPcrexformFree(de_ctx, pxd);
+        SCReturnInt(-1);
+    }
+    if (nb != 1) {
+        SCLogError("pcrexform needs exactly one substring capture, found %" PRIu32, nb);
+        DetectTransformPcrexformFree(de_ctx, pxd);
+        SCReturnInt(-1);
     }
 
     int r = DetectSignatureAddTransform(s, DETECT_TRANSFORM_PCREXFORM, pxd);
     if (r != 0) {
-        SCFree(pxd);
+        DetectTransformPcrexformFree(de_ctx, pxd);
     }
 
     SCReturnInt(r);
@@ -113,19 +138,20 @@ static void DetectTransformPcrexform(InspectionBuffer *buffer, void *options)
     const uint32_t input_len = buffer->inspect_len;
     DetectTransformPcrexformData *pxd = options;
 
-    int ov[MAX_SUBSTRINGS];
-    int ret = DetectParsePcreExecLen(pxd, input, input_len, 0, 0, ov, MAX_SUBSTRINGS);
+    pcre2_match_data *match = pcre2_match_data_create_from_pattern(pxd->regex, NULL);
+    int ret = pcre2_match(pxd->regex, (PCRE2_SPTR8)input, input_len, 0, 0, match, pxd->context);
 
     if (ret > 0) {
         const char *str;
-        ret = pcre_get_substring((char *) buffer->inspect, ov,
-                                  MAX_SUBSTRINGS, ret - 1, &str);
+        PCRE2_SIZE caplen;
+        ret = pcre2_substring_get_bynumber(match, 1, (PCRE2_UCHAR8 **)&str, &caplen);
 
         if (ret >= 0) {
-            InspectionBufferCopy(buffer, (uint8_t *)str, (uint32_t) ret);
-            pcre_free_substring(str);
+            InspectionBufferCopy(buffer, (uint8_t *)str, (uint32_t)caplen);
+            pcre2_substring_free((PCRE2_UCHAR8 *)str);
         }
     }
+    pcre2_match_data_free(match);
 }
 
 #ifdef UNITTESTS
