@@ -86,7 +86,7 @@ static int DetectUdphdrSetup (DetectEngineCtx *de_ctx, Signature *s, const char
 
     s->flags |= SIG_FLAG_REQUIRE_PACKET;
 
-    if (DetectBufferSetActiveList(s, g_udphdr_buffer_id) < 0)
+    if (DetectBufferSetActiveList(de_ctx, s, g_udphdr_buffer_id) < 0)
         return -1;
 
     return 0;
