@@ -25,13 +25,12 @@
 #define __IPPAIR_BIT_H__
 
 #include "ippair.h"
-#include "util-var.h"
 
 void IPPairBitInitCtx(void);
 void IPPairBitRegisterTests(void);
 
 int IPPairHasBits(IPPair *host);
-int IPPairBitsTimedoutCheck(IPPair *h, struct timeval *ts);
+int IPPairBitsTimedoutCheck(IPPair *h, SCTime_t ts);
 
 void IPPairBitSet(IPPair *, uint32_t, uint32_t);
 void IPPairBitUnset(IPPair *, uint32_t);
