@@ -25,7 +25,6 @@
 
 #include "suricata-common.h"
 #include "threads.h"
-#include "debug.h"
 #include "ippair-queue.h"
 #include "util-error.h"
 #include "util-debug.h"
@@ -44,7 +43,7 @@ IPPairQueue *IPPairQueueNew(void)
 {
     IPPairQueue *q = (IPPairQueue *)SCMalloc(sizeof(IPPairQueue));
     if (q == NULL) {
-        SCLogError(SC_ERR_FATAL, "Fatal error encountered in IPPairQueueNew. Exiting...");
+        SCLogError("Fatal error encountered in IPPairQueueNew. Exiting...");
         exit(EXIT_SUCCESS);
     }
     q = IPPairQueueInit(q);
