@@ -33,6 +33,7 @@
 #include "util-random.h"
 #include "util-misc.h"
 #include "util-byte.h"
+#include "util-validate.h"
 
 #include "ippair-queue.h"
 
@@ -165,11 +166,13 @@ void IPPairClearMemory(IPPair *h)
 
 /** \brief initialize the configuration
  *  \warning Not thread safe */
-void IPPairInitConfig(char quiet)
+void IPPairInitConfig(bool quiet)
 {
     SCLogDebug("initializing ippair engine...");
-    if (IPPairStorageSize() > 0)
-        g_ippair_size = sizeof(IPPair) + IPPairStorageSize();
+    if (IPPairStorageSize() > 0) {
+        DEBUG_VALIDATE_BUG_ON(sizeof(IPPair) + IPPairStorageSize() > UINT16_MAX);
+        g_ippair_size = (uint16_t)(sizeof(IPPair) + IPPairStorageSize());
+    }
 
     memset(&ippair_config,  0, sizeof(ippair_config));
     //SC_ATOMIC_INIT(flow_flags);
@@ -194,9 +197,9 @@ void IPPairInitConfig(char quiet)
     if ((ConfGet("ippair.memcap", &conf_val)) == 1)
     {
         if (ParseSizeStringU64(conf_val, &ippair_memcap) < 0) {
-            SCLogError(SC_ERR_SIZE_PARSE, "Error parsing ippair.memcap "
+            SCLogError("Error parsing ippair.memcap "
                        "from conf file - %s.  Killing engine",
-                       conf_val);
+                    conf_val);
             exit(EXIT_FAILURE);
         } else {
             SC_ATOMIC_SET(ippair_config.memcap, ippair_memcap);
@@ -226,18 +229,17 @@ void IPPairInitConfig(char quiet)
     /* alloc hash memory */
     uint64_t hash_size = ippair_config.hash_size * sizeof(IPPairHashRow);
     if (!(IPPAIR_CHECK_MEMCAP(hash_size))) {
-        SCLogError(SC_ERR_IPPAIR_INIT, "allocating ippair hash failed: "
-                "max ippair memcap is smaller than projected hash size. "
-                "Memcap: %"PRIu64", Hash table size %"PRIu64". Calculate "
-                "total hash size by multiplying \"ippair.hash-size\" with %"PRIuMAX", "
-                "which is the hash bucket size.", SC_ATOMIC_GET(ippair_config.memcap), hash_size,
-                (uintmax_t)sizeof(IPPairHashRow));
+        SCLogError("allocating ippair hash failed: "
+                   "max ippair memcap is smaller than projected hash size. "
+                   "Memcap: %" PRIu64 ", Hash table size %" PRIu64 ". Calculate "
+                   "total hash size by multiplying \"ippair.hash-size\" with %" PRIuMAX ", "
+                   "which is the hash bucket size.",
+                SC_ATOMIC_GET(ippair_config.memcap), hash_size, (uintmax_t)sizeof(IPPairHashRow));
         exit(EXIT_FAILURE);
     }
     ippair_hash = SCMallocAligned(ippair_config.hash_size * sizeof(IPPairHashRow), CLS);
     if (unlikely(ippair_hash == NULL)) {
-        FatalError(SC_ERR_FATAL,
-                   "Fatal error encountered in IPPairInitConfig. Exiting...");
+        FatalError("Fatal error encountered in IPPairInitConfig. Exiting...");
     }
     memset(ippair_hash, 0, ippair_config.hash_size * sizeof(IPPairHashRow));
 
@@ -247,7 +249,7 @@ void IPPairInitConfig(char quiet)
     }
     (void) SC_ATOMIC_ADD(ippair_memuse, (ippair_config.hash_size * sizeof(IPPairHashRow)));
 
-    if (quiet == FALSE) {
+    if (!quiet) {
         SCLogConfig("allocated %"PRIu64" bytes of memory for the ippair hash... "
                   "%" PRIu32 " buckets of size %" PRIuMAX "",
                   SC_ATOMIC_GET(ippair_memuse), ippair_config.hash_size,
@@ -257,22 +259,23 @@ void IPPairInitConfig(char quiet)
     /* pre allocate ippairs */
     for (i = 0; i < ippair_config.prealloc; i++) {
         if (!(IPPAIR_CHECK_MEMCAP(g_ippair_size))) {
-            SCLogError(SC_ERR_IPPAIR_INIT, "preallocating ippairs failed: "
-                    "max ippair memcap reached. Memcap %"PRIu64", "
-                    "Memuse %"PRIu64".", SC_ATOMIC_GET(ippair_config.memcap),
+            SCLogError("preallocating ippairs failed: "
+                       "max ippair memcap reached. Memcap %" PRIu64 ", "
+                       "Memuse %" PRIu64 ".",
+                    SC_ATOMIC_GET(ippair_config.memcap),
                     ((uint64_t)SC_ATOMIC_GET(ippair_memuse) + g_ippair_size));
             exit(EXIT_FAILURE);
         }
 
         IPPair *h = IPPairAlloc();
         if (h == NULL) {
-            SCLogError(SC_ERR_IPPAIR_INIT, "preallocating ippair failed: %s", strerror(errno));
+            SCLogError("preallocating ippair failed: %s", strerror(errno));
             exit(EXIT_FAILURE);
         }
         IPPairEnqueue(&ippair_spare_q,h);
     }
 
-    if (quiet == FALSE) {
+    if (!quiet) {
         SCLogConfig("preallocated %" PRIu32 " ippairs of size %" PRIu16 "",
                 ippair_spare_q.len, g_ippair_size);
         SCLogConfig("ippair memory usage: %"PRIu64" bytes, maximum: %"PRIu64,
@@ -500,7 +503,7 @@ static IPPair *IPPairGetNew(Address *a, Address *b)
     } else {
         /* ippair has been recycled before it went into the spare queue */
 
-        /* ippair is initialized (recylced) but *unlocked* */
+        /* ippair is initialized (recycled) but *unlocked* */
     }
 
     (void) SC_ATOMIC_ADD(ippair_counter, 1);
