@@ -25,7 +25,6 @@
  */
 
 #include "suricata-common.h"
-#include "debug.h"
 #include "detect.h"
 #include "pkt-var.h"
 #include "conf.h"
@@ -65,9 +64,8 @@ int LogHttpLogger(ThreadVars *tv, void *thread_data, const Packet *, Flow *f, vo
 
 void LogHttpLogRegister (void)
 {
-    OutputRegisterTxModule(LOGGER_HTTP, MODULE_NAME, "http-log",
-        LogHttpLogInitCtx, ALPROTO_HTTP, LogHttpLogger, LogHttpLogThreadInit,
-        LogHttpLogThreadDeinit, NULL);
+    OutputRegisterTxModule(LOGGER_HTTP, MODULE_NAME, "http-log", LogHttpLogInitCtx, ALPROTO_HTTP1,
+            LogHttpLogger, LogHttpLogThreadInit, LogHttpLogThreadDeinit, NULL);
 }
 
 #define LOG_HTTP_CF_REQUEST_HOST 'h'
@@ -128,8 +126,8 @@ static uint32_t GetCookieValue(uint8_t *rawcookies, uint32_t rawcookies_len, cha
 }
 
 /* Custom format logging */
-static void LogHttpLogCustom(LogHttpLogThread *aft, htp_tx_t *tx, const struct timeval *ts,
-                                            char *srcip, Port sp, char *dstip, Port dp)
+static void LogHttpLogCustom(LogHttpLogThread *aft, htp_tx_t *tx, const SCTime_t ts, char *srcip,
+        Port sp, char *dstip, Port dp)
 {
     LogHttpFileCtx *httplog_ctx = aft->httplog_ctx;
     uint32_t i;
@@ -157,14 +155,14 @@ static void LogHttpLogCustom(LogHttpLogThread *aft, htp_tx_t *tx, const struct t
                 break;
             case LOG_CF_TIMESTAMP:
             /* TIMESTAMP */
-                LogCustomFormatWriteTimestamp(aft->buffer, node->data, ts);
-                break;
+            LogCustomFormatWriteTimestamp(aft->buffer, node->data, ts);
+            break;
             case LOG_CF_TIMESTAMP_U:
             /* TIMESTAMP USECONDS */
-                snprintf(buf, sizeof(buf), "%06u", (unsigned int) ts->tv_usec);
-                PrintRawUriBuf((char *)aft->buffer->buffer, &aft->buffer->offset,
-                            aft->buffer->size, (uint8_t *)buf, MIN(strlen(buf),6));
-                break;
+            snprintf(buf, sizeof(buf), "%06u", (unsigned int)SCTIME_USECS(ts));
+            PrintRawUriBuf((char *)aft->buffer->buffer, &aft->buffer->offset, aft->buffer->size,
+                    (uint8_t *)buf, MIN(strlen(buf), 6));
+            break;
             case LOG_CF_CLIENT_IP:
             /* CLIENT IP ADDRESS */
                 PrintRawUriBuf((char *)aft->buffer->buffer, &aft->buffer->offset,
@@ -318,7 +316,7 @@ static void LogHttpLogCustom(LogHttpLogThread *aft, htp_tx_t *tx, const struct t
 
 static void LogHttpLogExtended(LogHttpLogThread *aft, htp_tx_t *tx)
 {
-    LOG_CF_WRITE_STAR_SEPATATOR(aft->buffer);
+    LOG_CF_WRITE_STAR_SEPARATOR(aft->buffer);
 
     /* referer */
     htp_header_t *h_referer = NULL;
@@ -333,7 +331,7 @@ static void LogHttpLogExtended(LogHttpLogThread *aft, htp_tx_t *tx)
         MemBufferWriteString(aft->buffer, "<no referer>");
     }
 
-    LOG_CF_WRITE_STAR_SEPATATOR(aft->buffer);
+    LOG_CF_WRITE_STAR_SEPARATOR(aft->buffer);
 
     /* method */
     if (tx->request_method != NULL) {
@@ -341,7 +339,7 @@ static void LogHttpLogExtended(LogHttpLogThread *aft, htp_tx_t *tx)
                        (uint8_t *)bstr_ptr(tx->request_method),
                        bstr_len(tx->request_method));
     }
-    LOG_CF_WRITE_STAR_SEPATATOR(aft->buffer);
+    LOG_CF_WRITE_STAR_SEPARATOR(aft->buffer);
 
     /* protocol */
     if (tx->request_protocol != NULL) {
@@ -351,7 +349,7 @@ static void LogHttpLogExtended(LogHttpLogThread *aft, htp_tx_t *tx)
     } else {
         MemBufferWriteString(aft->buffer, "<no protocol>");
     }
-    LOG_CF_WRITE_STAR_SEPATATOR(aft->buffer);
+    LOG_CF_WRITE_STAR_SEPARATOR(aft->buffer);
 
     /* response status */
     if (tx->response_status != NULL) {
@@ -374,7 +372,7 @@ static void LogHttpLogExtended(LogHttpLogThread *aft, htp_tx_t *tx)
     }
 
     /* length */
-    LOG_CF_WRITE_STAR_SEPATATOR(aft->buffer);
+    LOG_CF_WRITE_STAR_SEPARATOR(aft->buffer);
     MemBufferWriteString(aft->buffer, "%"PRIuMAX" bytes", (uintmax_t)tx->response_message_len);
 }
 
@@ -387,7 +385,7 @@ static TmEcode LogHttpLogIPWrapper(ThreadVars *tv, void *data, const Packet *p,
     char timebuf[64];
 
     /* check if we have HTTP state or not */
-    CreateTimeString(&p->ts, timebuf, sizeof(timebuf));
+    CreateTimeString(p->ts, timebuf, sizeof(timebuf));
 
     char srcip[46], dstip[46];
     Port sp, dp;
@@ -429,7 +427,7 @@ static TmEcode LogHttpLogIPWrapper(ThreadVars *tv, void *data, const Packet *p,
     MemBufferReset(aft->buffer);
 
     if (hlog->flags & LOG_HTTP_CUSTOM) {
-        LogHttpLogCustom(aft, tx, &p->ts, srcip, sp, dstip, dp);
+        LogHttpLogCustom(aft, tx, p->ts, srcip, sp, dstip, dp);
     } else {
         /* time */
         MemBufferWriteString(aft->buffer, "%s ", timebuf);
@@ -442,7 +440,7 @@ static TmEcode LogHttpLogIPWrapper(ThreadVars *tv, void *data, const Packet *p,
         } else {
             MemBufferWriteString(aft->buffer, "<hostname unknown>");
         }
-        LOG_CF_WRITE_STAR_SEPATATOR(aft->buffer);
+        LOG_CF_WRITE_STAR_SEPARATOR(aft->buffer);
 
         /* uri */
         if (tx->request_uri != NULL) {
@@ -450,7 +448,7 @@ static TmEcode LogHttpLogIPWrapper(ThreadVars *tv, void *data, const Packet *p,
                     (uint8_t *)bstr_ptr(tx->request_uri),
                     bstr_len(tx->request_uri));
         }
-        LOG_CF_WRITE_STAR_SEPATATOR(aft->buffer);
+        LOG_CF_WRITE_STAR_SEPARATOR(aft->buffer);
 
         /* user agent */
         htp_header_t *h_user_agent = NULL;
@@ -469,7 +467,7 @@ static TmEcode LogHttpLogIPWrapper(ThreadVars *tv, void *data, const Packet *p,
         }
 
         /* ip/tcp header info */
-        LOG_CF_WRITE_STAR_SEPATATOR(aft->buffer);
+        LOG_CF_WRITE_STAR_SEPARATOR(aft->buffer);
         MemBufferWriteString(aft->buffer,
                 "%s:%" PRIu16 " -> %s:%" PRIu16 "\n",
                 srcip, sp, dstip, dp);
@@ -523,7 +521,7 @@ TmEcode LogHttpLogThreadInit(ThreadVars *t, const void *initdata, void **data)
         return TM_ECODE_FAILED;
     }
 
-    /* Use the Ouptut Context (file pointer and mutex) */
+    /* Use the Output Context (file pointer and mutex) */
     aft->httplog_ctx= ((OutputCtx *)initdata)->data;
 
     *data = (void *)aft;
@@ -554,7 +552,7 @@ OutputInitResult LogHttpLogInitCtx(ConfNode *conf)
     OutputInitResult result = { NULL, false };
     LogFileCtx* file_ctx = LogFileNewCtx();
     if(file_ctx == NULL) {
-        SCLogError(SC_ERR_HTTP_LOG_GENERIC, "couldn't create new file_ctx");
+        SCLogError("couldn't create new file_ctx");
         return result;
     }
 
@@ -611,14 +609,14 @@ OutputInitResult LogHttpLogInitCtx(ConfNode *conf)
     SCLogDebug("HTTP log output initialized");
 
     /* enable the logger for the app layer */
-    AppLayerParserRegisterLogger(IPPROTO_TCP, ALPROTO_HTTP);
+    AppLayerParserRegisterLogger(IPPROTO_TCP, ALPROTO_HTTP1);
 
     result.ctx = output_ctx;
     result.ok = true;
     return result;
 
 parsererror:
-    SCLogError(SC_ERR_INVALID_ARGUMENT,"Syntax error in custom http log format string.");
+    SCLogError("Syntax error in custom http log format string.");
 errorfree:
     LogCustomFormatFree(httplog_ctx->cf);
     LogFileFreeCtx(file_ctx);
