@@ -24,6 +24,9 @@
 #ifndef __LOG_TCPDATALOG_H__
 #define __LOG_TCPDATALOG_H__
 
+#include "conf.h"
+#include "output.h"
+
 void LogTcpDataLogRegister(void);
 OutputInitResult LogTcpDataLogInitCtx(ConfNode *);
 
