@@ -28,8 +28,6 @@
 #define __OUTPUT_JSON_ANOMALY_H__
 
 void JsonAnomalyLogRegister(void);
-void AnomalyJsonHeader(void *ctx, const Packet *p, const PacketAlert *pa, json_t *js,
-                     uint16_t flags);
 
 #endif /* __OUTPUT_JSON_ALERT_H__ */
 
