@@ -1,4 +1,4 @@
-/* Copyright (C) 2017-2020 Open Information Security Foundation
+/* Copyright (C) 2017-2021 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -24,27 +24,11 @@
  */
 
 #include "suricata-common.h"
-#include "debug.h"
-#include "pkt-var.h"
-#include "conf.h"
-
-#include "threads.h"
-#include "threadvars.h"
-#include "tm-threads.h"
-
-#include "util-unittest.h"
 #include "util-buffer.h"
-#include "util-debug.h"
-#include "util-byte.h"
-
 #include "output.h"
 #include "output-json.h"
-
-#include "app-layer.h"
 #include "app-layer-parser.h"
-
 #include "output-json-smb.h"
-
 #include "rust.h"
 
 bool EveSMBAddMetadata(const Flow *f, uint64_t tx_id, JsonBuilder *jb)
@@ -64,7 +48,7 @@ static int JsonSMBLogger(ThreadVars *tv, void *thread_data,
 {
     OutputJsonThreadCtx *thread = thread_data;
 
-    JsonBuilder *jb = CreateEveHeader(p, LOG_DIR_FLOW, "smb", NULL);
+    JsonBuilder *jb = CreateEveHeader(p, LOG_DIR_FLOW, "smb", NULL, thread->ctx);
     if (unlikely(jb == NULL)) {
         return TM_ECODE_FAILED;
     }
@@ -75,9 +59,7 @@ static int JsonSMBLogger(ThreadVars *tv, void *thread_data,
     }
     jb_close(jb);
 
-    EveAddCommonOptions(&thread->ctx->cfg, p, f, jb);
-    MemBufferReset(thread->buffer);
-    OutputJsonBuilderBuffer(jb, thread->file_ctx, &thread->buffer);
+    OutputJsonBuilderBuffer(jb, thread);
 
     jb_free(jb);
     return TM_ECODE_OK;
@@ -97,10 +79,8 @@ static OutputInitResult SMBLogInitSub(ConfNode *conf, OutputCtx *parent_ctx)
 void JsonSMBLogRegister(void)
 {
     /* Register as an eve sub-module. */
-    OutputRegisterTxSubModule(LOGGER_JSON_SMB, "eve-log", "JsonSMBLog",
-        "eve-log.smb", SMBLogInitSub, ALPROTO_SMB,
-        JsonSMBLogger, JsonLogThreadInit,
-        JsonLogThreadDeinit, NULL);
+    OutputRegisterTxSubModule(LOGGER_JSON_TX, "eve-log", "JsonSMBLog", "eve-log.smb", SMBLogInitSub,
+            ALPROTO_SMB, JsonSMBLogger, JsonLogThreadInit, JsonLogThreadDeinit, NULL);
 
     SCLogDebug("SMB JSON logger registered.");
 }
