@@ -1,4 +1,4 @@
-/* Copyright (C) 2007-2016 Open Information Security Foundation
+/* Copyright (C) 2007-2021 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -42,7 +42,6 @@
 
 #include "alert-fastlog.h"
 #include "alert-debuglog.h"
-#include "alert-prelude.h"
 #include "alert-syslog.h"
 #include "output-json.h"
 #include "output-json-alert.h"
@@ -51,9 +50,11 @@
 #include "output-json-netflow.h"
 #include "log-cf-common.h"
 #include "output-json-drop.h"
+#include "output-eve-stream.h"
 #include "log-httplog.h"
 #include "output-json-http.h"
 #include "output-json-dns.h"
+#include "output-json-modbus.h"
 #include "log-tlslog.h"
 #include "log-tlsstore.h"
 #include "output-json-tls.h"
@@ -64,26 +65,28 @@
 #include "output-json-stats.h"
 #include "log-tcp-data.h"
 #include "log-stats.h"
-#include "output-json.h"
 #include "output-json-nfs.h"
 #include "output-json-ftp.h"
 #include "output-json-tftp.h"
 #include "output-json-smb.h"
-#include "output-json-ikev2.h"
+#include "output-json-ike.h"
 #include "output-json-krb5.h"
+#include "output-json-quic.h"
 #include "output-json-dhcp.h"
 #include "output-json-snmp.h"
 #include "output-json-sip.h"
 #include "output-json-rfb.h"
 #include "output-json-mqtt.h"
+#include "output-json-pgsql.h"
 #include "output-json-template.h"
-#include "output-json-template-rust.h"
 #include "output-json-rdp.h"
 #include "output-json-http2.h"
 #include "output-lua.h"
 #include "output-json-dnp3.h"
 #include "output-json-metadata.h"
 #include "output-json-dcerpc.h"
+#include "output-json-frame.h"
+#include "output-json-bittorrent-dht.h"
 #include "output-filestore.h"
 
 typedef struct RootLogger_ {
@@ -159,8 +162,7 @@ void OutputRegisterModule(const char *name, const char *conf_name,
     return;
 
 error:
-    FatalError(SC_ERR_FATAL,
-               "Fatal error encountered in OutputRegisterModule. Exiting...");
+    FatalError("Fatal error encountered in OutputRegisterModule. Exiting...");
 }
 
 /**
@@ -200,7 +202,7 @@ void OutputRegisterPacketModule(LoggerId id, const char *name,
     SCLogDebug("Packet logger \"%s\" registered.", name);
     return;
 error:
-    FatalError(SC_ERR_FATAL, "Fatal error encountered. Exiting...");
+    FatalError("Fatal error encountered. Exiting...");
 }
 
 /**
@@ -241,7 +243,7 @@ void OutputRegisterPacketSubModule(LoggerId id, const char *parent_name,
     SCLogDebug("Packet logger \"%s\" registered.", name);
     return;
 error:
-    FatalError(SC_ERR_FATAL, "Fatal error encountered. Exiting...");
+    FatalError("Fatal error encountered. Exiting...");
 }
 
 /**
@@ -285,7 +287,7 @@ static void OutputRegisterTxModuleWrapper(LoggerId id, const char *name,
     SCLogDebug("Tx logger \"%s\" registered.", name);
     return;
 error:
-    FatalError(SC_ERR_FATAL, "Fatal error encountered. Exiting...");
+    FatalError("Fatal error encountered. Exiting...");
 }
 
 static void OutputRegisterTxSubModuleWrapper(LoggerId id, const char *parent_name,
@@ -322,7 +324,7 @@ static void OutputRegisterTxSubModuleWrapper(LoggerId id, const char *parent_nam
     SCLogDebug("Tx logger for alproto %d \"%s\" registered.", alproto, name);
     return;
 error:
-    FatalError(SC_ERR_FATAL, "Fatal error encountered. Exiting...");
+    FatalError("Fatal error encountered. Exiting...");
 }
 
 /**
@@ -452,7 +454,7 @@ void OutputRegisterFileModule(LoggerId id, const char *name,
     SCLogDebug("File logger \"%s\" registered.", name);
     return;
 error:
-    FatalError(SC_ERR_FATAL, "Fatal error encountered. Exiting...");
+    FatalError("Fatal error encountered. Exiting...");
 }
 
 /**
@@ -492,7 +494,7 @@ void OutputRegisterFileSubModule(LoggerId id, const char *parent_name,
     SCLogDebug("File logger \"%s\" registered.", name);
     return;
 error:
-    FatalError(SC_ERR_FATAL, "Fatal error encountered. Exiting...");
+    FatalError("Fatal error encountered. Exiting...");
 }
 
 /**
@@ -531,7 +533,7 @@ void OutputRegisterFiledataModule(LoggerId id, const char *name,
     SCLogDebug("Filedata logger \"%s\" registered.", name);
     return;
 error:
-    FatalError(SC_ERR_FATAL, "Fatal error encountered. Exiting...");
+    FatalError("Fatal error encountered. Exiting...");
 }
 
 /**
@@ -571,7 +573,7 @@ void OutputRegisterFiledataSubModule(LoggerId id, const char *parent_name,
     SCLogDebug("Filedata logger \"%s\" registered.", name);
     return;
 error:
-    FatalError(SC_ERR_FATAL, "Fatal error encountered. Exiting...");
+    FatalError("Fatal error encountered. Exiting...");
 }
 
 /**
@@ -611,7 +613,7 @@ void OutputRegisterFlowSubModule(LoggerId id, const char *parent_name,
     SCLogDebug("Flow logger \"%s\" registered.", name);
     return;
 error:
-    FatalError(SC_ERR_FATAL, "Fatal error encountered. Exiting...");
+    FatalError("Fatal error encountered. Exiting...");
 }
 
 /**
@@ -652,7 +654,7 @@ void OutputRegisterStreamingModule(LoggerId id, const char *name,
     SCLogDebug("Streaming logger \"%s\" registered.", name);
     return;
 error:
-    FatalError(SC_ERR_FATAL, "Fatal error encountered. Exiting...");
+    FatalError("Fatal error encountered. Exiting...");
 }
 
 /**
@@ -693,7 +695,7 @@ void OutputRegisterStreamingSubModule(LoggerId id, const char *parent_name,
     SCLogDebug("Streaming logger \"%s\" registered.", name);
     return;
 error:
-    FatalError(SC_ERR_FATAL, "Fatal error encountered. Exiting...");
+    FatalError("Fatal error encountered. Exiting...");
 }
 
 /**
@@ -731,7 +733,7 @@ void OutputRegisterStatsModule(LoggerId id, const char *name,
     SCLogDebug("Stats logger \"%s\" registered.", name);
     return;
 error:
-    FatalError(SC_ERR_FATAL, "Fatal error encountered. Exiting...");
+    FatalError("Fatal error encountered. Exiting...");
 }
 
 /**
@@ -771,7 +773,7 @@ void OutputRegisterStatsSubModule(LoggerId id, const char *parent_name,
     SCLogDebug("Stats logger \"%s\" registered.", name);
     return;
 error:
-    FatalError(SC_ERR_FATAL, "Fatal error encountered. Exiting...");
+    FatalError("Fatal error encountered. Exiting...");
 }
 
 /**
@@ -831,8 +833,7 @@ void OutputRegisterFileRotationFlag(int *flag)
 {
     OutputFileRolloverFlag *flag_entry = SCCalloc(1, sizeof(*flag_entry));
     if (unlikely(flag_entry == NULL)) {
-        SCLogError(SC_ERR_MEM_ALLOC,
-            "Failed to allocate memory to register file rotation flag");
+        SCLogError("Failed to allocate memory to register file rotation flag");
         return;
     }
     flag_entry->flag = flag;
@@ -884,7 +885,6 @@ TmEcode OutputLoggerLog(ThreadVars *tv, Packet *p, void *thread_data)
         logger = TAILQ_NEXT(logger, entries);
         thread_store_node = TAILQ_NEXT(thread_store_node, entries);
     }
-
     return TM_ECODE_OK;
 }
 
@@ -968,7 +968,7 @@ void OutputRegisterRootLogger(ThreadInitFunc ThreadInit,
 
     RootLogger *logger = SCCalloc(1, sizeof(*logger));
     if (logger == NULL) {
-        FatalError(SC_ERR_MEM_ALLOC, "failed to alloc root logger");
+        FatalError("failed to alloc root logger");
     }
     logger->ThreadInit = ThreadInit;
     logger->ThreadDeinit = ThreadDeinit;
@@ -982,7 +982,7 @@ static void OutputRegisterActiveLogger(RootLogger *reg)
 {
     RootLogger *logger = SCCalloc(1, sizeof(*logger));
     if (logger == NULL) {
-        FatalError(SC_ERR_MEM_ALLOC, "failed to alloc root logger");
+        FatalError("failed to alloc root logger");
     }
     logger->ThreadInit = reg->ThreadInit;
     logger->ThreadDeinit = reg->ThreadDeinit;
@@ -1026,9 +1026,9 @@ void TmModuleLoggerRegister(void)
 void OutputRegisterRootLoggers(void)
 {
     OutputPacketLoggerRegister();
-    OutputTxLoggerRegister();
     OutputFiledataLoggerRegister();
     OutputFileLoggerRegister();
+    OutputTxLoggerRegister();
     OutputStreamingLoggerRegister();
 }
 
@@ -1045,11 +1045,10 @@ void OutputRegisterLoggers(void)
     AlertFastLogRegister();
     /* debug log */
     AlertDebugLogRegister();
-    /* prelue log */
-    AlertPreludeRegister();
     /* syslog log */
     AlertSyslogRegister();
     JsonDropLogRegister();
+    EveStreamLogRegister();
     /* json log */
     OutputJsonRegister();
     /* email logs */
@@ -1071,6 +1070,8 @@ void OutputRegisterLoggers(void)
     OutputFilestoreRegister();
     /* dns */
     JsonDnsLogRegister();
+    /* modbus */
+    JsonModbusLogRegister();
     /* tcp streaming data */
     LogTcpDataLogRegister();
     /* log stats */
@@ -1096,10 +1097,12 @@ void OutputRegisterLoggers(void)
     JsonFTPLogRegister();
     /* SMB JSON logger. */
     JsonSMBLogRegister();
-    /* IKEv2 JSON logger. */
-    JsonIKEv2LogRegister();
+    /* IKE JSON logger. */
+    JsonIKELogRegister();
     /* KRB5 JSON logger. */
     JsonKRB5LogRegister();
+    /* QUIC JSON logger. */
+    JsonQuicLogRegister();
     /* DHCP JSON logger. */
     JsonDHCPLogRegister();
     /* SNMP JSON logger. */
@@ -1110,12 +1113,16 @@ void OutputRegisterLoggers(void)
     JsonRFBLogRegister();
     /* MQTT JSON logger. */
     JsonMQTTLogRegister();
+    /* Pgsql JSON logger. */
+    JsonPgsqlLogRegister();
     /* Template JSON logger. */
     JsonTemplateLogRegister();
-    /* Template Rust JSON logger. */
-    JsonTemplateRustLogRegister();
     /* RDP JSON logger. */
     JsonRdpLogRegister();
     /* DCERPC JSON logger. */
     JsonDCERPCLogRegister();
+    /* app layer frames */
+    JsonFrameLogRegister();
+    /* BitTorrent DHT JSON logger */
+    JsonBitTorrentDHTLogRegister();
 }
