@@ -18,6 +18,10 @@
 #ifndef __RUST_H__
 #define __RUST_H__
 
+#include "util-file.h"
+
+// hack for include orders cf SCSha256
+typedef struct HttpRangeContainerBlock HttpRangeContainerBlock;
 #include "rust-context.h"
 #include "rust-bindings.h"
 
