@@ -29,8 +29,10 @@
 #include "source-pcap-file-directory-helper.h"
 #include "flow-manager.h"
 #include "util-checksum.h"
+#include "runmode-unix-socket.h"
+#include "suricata.h"
 
-extern intmax_t max_pending_packets;
+extern uint16_t max_pending_packets;
 PcapFileGlobalVars pcap_g;
 
 /**
@@ -84,25 +86,25 @@ void CleanupPcapDirectoryFromThreadVars(PcapFileThreadVars *tv, PcapFileDirector
     }
 }
 
-void CleanupPcapFileThreadVars(PcapFileThreadVars *tv)
+void CleanupPcapFileThreadVars(PcapFileThreadVars *ptv)
 {
-    if(tv != NULL) {
-        if (tv->is_directory == 0) {
-            if (tv->behavior.file != NULL) {
-                CleanupPcapFileFromThreadVars(tv, tv->behavior.file);
+    if (ptv != NULL) {
+        if (ptv->is_directory == 0) {
+            if (ptv->behavior.file != NULL) {
+                CleanupPcapFileFromThreadVars(ptv, ptv->behavior.file);
             }
-            tv->behavior.file = NULL;
+            ptv->behavior.file = NULL;
         } else {
-            if (tv->behavior.directory != NULL) {
-                CleanupPcapDirectoryFromThreadVars(tv, tv->behavior.directory);
+            if (ptv->behavior.directory != NULL) {
+                CleanupPcapDirectoryFromThreadVars(ptv, ptv->behavior.directory);
             }
-            tv->behavior.directory = NULL;
+            ptv->behavior.directory = NULL;
         }
-        if (tv->shared.bpf_string != NULL) {
-            SCFree(tv->shared.bpf_string);
-            tv->shared.bpf_string = NULL;
+        if (ptv->shared.bpf_string != NULL) {
+            SCFree(ptv->shared.bpf_string);
+            ptv->shared.bpf_string = NULL;
         }
-        SCFree(tv);
+        SCFree(ptv);
     }
 }
 
@@ -155,7 +157,7 @@ TmEcode ReceivePcapFileLoop(ThreadVars *tv, void *data, void *slot)
     SCEnter();
 
     if(unlikely(data == NULL)) {
-        SCLogError(SC_ERR_INVALID_ARGUMENT, "pcap file reader thread failed to initialize");
+        SCLogError("pcap file reader thread failed to initialize");
 
         PcapFileExit(TM_ECODE_FAILED, NULL);
 
@@ -169,6 +171,10 @@ TmEcode ReceivePcapFileLoop(ThreadVars *tv, void *data, void *slot)
     ptv->shared.slot = s->slot_next;
     ptv->shared.cb_result = TM_ECODE_OK;
 
+    // Indicate that the thread is actually running its application level code (i.e., it can poll
+    // packets)
+    TmThreadsSetFlag(tv, THV_RUNNING);
+
     if(ptv->is_directory == 0) {
         SCLogInfo("Starting file run for %s", ptv->behavior.file->filename);
         status = PcapFileDispatch(ptv->behavior.file);
@@ -194,7 +200,7 @@ TmEcode ReceivePcapFileThreadInit(ThreadVars *tv, const void *initdata, void **d
     const char *tmp_bpf_string = NULL;
 
     if (initdata == NULL) {
-        SCLogError(SC_ERR_INVALID_ARGUMENT, "error: initdata == NULL");
+        SCLogError("error: initdata == NULL");
 
         SCReturnInt(TM_ECODE_OK);
     }
@@ -212,7 +218,7 @@ TmEcode ReceivePcapFileThreadInit(ThreadVars *tv, const void *initdata, void **d
             ptv->shared.tenant_id = (uint32_t)tenant;
             SCLogInfo("tenant %u", ptv->shared.tenant_id);
         } else {
-            SCLogError(SC_ERR_INVALID_ARGUMENT, "tenant out of range");
+            SCLogError("tenant out of range");
         }
     }
 
@@ -221,7 +227,7 @@ TmEcode ReceivePcapFileThreadInit(ThreadVars *tv, const void *initdata, void **d
     } else {
         ptv->shared.bpf_string = SCStrdup(tmp_bpf_string);
         if (unlikely(ptv->shared.bpf_string == NULL)) {
-            SCLogError(SC_ERR_MEM_ALLOC, "Failed to allocate bpf_string");
+            SCLogError("Failed to allocate bpf_string");
 
             CleanupPcapFileThreadVars(ptv);
 
@@ -246,7 +252,7 @@ TmEcode ReceivePcapFileThreadInit(ThreadVars *tv, const void *initdata, void **d
         SCLogDebug("argument %s was a file", (char *)initdata);
         PcapFileFileVars *pv = SCMalloc(sizeof(PcapFileFileVars));
         if (unlikely(pv == NULL)) {
-            SCLogError(SC_ERR_MEM_ALLOC, "Failed to allocate file vars");
+            SCLogError("Failed to allocate file vars");
             CleanupPcapFileThreadVars(ptv);
             SCReturnInt(TM_ECODE_OK);
         }
@@ -254,7 +260,7 @@ TmEcode ReceivePcapFileThreadInit(ThreadVars *tv, const void *initdata, void **d
 
         pv->filename = SCStrdup((char *)initdata);
         if (unlikely(pv->filename == NULL)) {
-            SCLogError(SC_ERR_MEM_ALLOC, "Failed to allocate filename");
+            SCLogError("Failed to allocate filename");
             CleanupPcapFileFileVars(pv);
             CleanupPcapFileThreadVars(ptv);
             SCReturnInt(TM_ECODE_OK);
@@ -266,8 +272,7 @@ TmEcode ReceivePcapFileThreadInit(ThreadVars *tv, const void *initdata, void **d
             ptv->is_directory = 0;
             ptv->behavior.file = pv;
         } else {
-            SCLogWarning(SC_ERR_PCAP_DISPATCH,
-                         "Failed to init pcap file %s, skipping", pv->filename);
+            SCLogWarning("Failed to init pcap file %s, skipping", pv->filename);
             CleanupPcapFileFileVars(pv);
             CleanupPcapFileThreadVars(ptv);
             SCReturnInt(TM_ECODE_OK);
@@ -276,7 +281,7 @@ TmEcode ReceivePcapFileThreadInit(ThreadVars *tv, const void *initdata, void **d
         SCLogInfo("Argument %s was a directory", (char *)initdata);
         PcapFileDirectoryVars *pv = SCMalloc(sizeof(PcapFileDirectoryVars));
         if (unlikely(pv == NULL)) {
-            SCLogError(SC_ERR_MEM_ALLOC, "Failed to allocate directory vars");
+            SCLogError("Failed to allocate directory vars");
             closedir(directory);
             CleanupPcapFileThreadVars(ptv);
             SCReturnInt(TM_ECODE_OK);
@@ -285,7 +290,7 @@ TmEcode ReceivePcapFileThreadInit(ThreadVars *tv, const void *initdata, void **d
 
         pv->filename = SCStrdup((char*)initdata);
         if (unlikely(pv->filename == NULL)) {
-            SCLogError(SC_ERR_MEM_ALLOC, "Failed to allocate filename");
+            SCLogError("Failed to allocate filename");
             CleanupPcapFileDirectoryVars(pv);
             CleanupPcapFileThreadVars(ptv);
             SCReturnInt(TM_ECODE_OK);
@@ -305,8 +310,8 @@ TmEcode ReceivePcapFileThreadInit(ThreadVars *tv, const void *initdata, void **d
         }
 
         if (pv->should_recurse == true && pv->should_loop == true) {
-            SCLogError(SC_ERR_INVALID_ARGUMENT, "Error, --pcap-file-continuous and --pcap-file-recursive "
-                                                "cannot be used together.");
+            SCLogError("Error, --pcap-file-continuous and --pcap-file-recursive "
+                       "cannot be used together.");
             CleanupPcapFileDirectoryVars(pv);
             CleanupPcapFileThreadVars(ptv);
             SCReturnInt(TM_ECODE_FAILED);
@@ -319,7 +324,7 @@ TmEcode ReceivePcapFileThreadInit(ThreadVars *tv, const void *initdata, void **d
                 pv->delay = (time_t)delay;
                 SCLogDebug("delay %lu", pv->delay);
             } else {
-                SCLogError(SC_ERR_INVALID_ARGUMENT, "delay out of range");
+                SCLogError("delay out of range");
             }
         }
 
@@ -330,7 +335,7 @@ TmEcode ReceivePcapFileThreadInit(ThreadVars *tv, const void *initdata, void **d
                 pv->poll_interval = (time_t)poll_interval;
                 SCLogDebug("poll-interval %lu", pv->delay);
             } else {
-                SCLogError(SC_ERR_INVALID_ARGUMENT, "poll-interval out of range");
+                SCLogError("poll-interval out of range");
             }
         }
 
@@ -372,21 +377,17 @@ void ReceivePcapFileThreadExitStats(ThreadVars *tv, void *data)
             SC_ATOMIC_GET(pcap_g.invalid_checksums)) {
             uint64_t chrate = pcap_g.cnt / SC_ATOMIC_GET(pcap_g.invalid_checksums);
             if (chrate < CHECKSUM_INVALID_RATIO)
-                SCLogWarning(SC_ERR_INVALID_CHECKSUM,
-                         "1/%" PRIu64 "th of packets have an invalid checksum,"
-                                 " consider setting pcap-file.checksum-checks variable to no"
-                                 " or use '-k none' option on command line.",
-                         chrate);
+                SCLogWarning("1/%" PRIu64 "th of packets have an invalid checksum,"
+                             " consider setting pcap-file.checksum-checks variable to no"
+                             " or use '-k none' option on command line.",
+                        chrate);
             else
                 SCLogInfo("1/%" PRIu64 "th of packets have an invalid checksum",
                       chrate);
         }
-        SCLogNotice(
-            "Pcap-file module read %" PRIu64 " files, %" PRIu64 " packets, %" PRIu64 " bytes",
-            ptv->shared.files,
-            ptv->shared.pkts,
-            ptv->shared.bytes
-        );
+        SCLogNotice("read %" PRIu64 " file%s, %" PRIu64 " packets, %" PRIu64 " bytes",
+                ptv->shared.files, ptv->shared.files == 1 ? "" : "s", ptv->shared.pkts,
+                ptv->shared.bytes);
     }
 }
 
@@ -400,8 +401,6 @@ TmEcode ReceivePcapFileThreadDeinit(ThreadVars *tv, void *data)
     SCReturnInt(TM_ECODE_OK);
 }
 
-static double prev_signaled_ts = 0;
-
 static TmEcode DecodePcapFile(ThreadVars *tv, Packet *p, void *data)
 {
     SCEnter();
@@ -412,14 +411,6 @@ static TmEcode DecodePcapFile(ThreadVars *tv, Packet *p, void *data)
     /* update counters */
     DecodeUpdatePacketCounters(tv, dtv, p);
 
-    double curr_ts = p->ts.tv_sec + p->ts.tv_usec / 1000.0;
-    if (curr_ts < prev_signaled_ts || (curr_ts - prev_signaled_ts) > 60.0) {
-        prev_signaled_ts = curr_ts;
-#if 0
-        FlowWakeupFlowManagerThread();
-#endif
-    }
-
     DecoderFunc decoder;
     if(ValidateLinkType(p->datalink, &decoder) == TM_ECODE_OK) {
 
