@@ -24,6 +24,7 @@
  */
 
 #include "suricata-common.h"
+#include "decode.h"
 #include "stream-tcp-private.h"
 #include "stream-tcp-inline.h"
 
@@ -84,10 +85,10 @@ int StreamTcpInlineSegmentCompare(const TcpStream *stream,
         SCLogDebug("pkt_end %u, seg_end %u", pkt_end, seg_end);
 
         /* get the minimal seg*_end */
-        uint32_t end = (SEQ_GT(pkt_end, seg_end)) ? seg_end : pkt_end;
+        uint32_t end = SEQ_MIN(seg_end, pkt_end);
         /* and the max seq */
-        uint32_t seq = (SEQ_LT(pkt_seq, seg_seq)) ? seg->seq : pkt_seq;
-        seq = (SEQ_GT(seq, stream->base_seq)) ? seq : stream->base_seq;
+        uint32_t seq = SEQ_MAX(pkt_seq, seg_seq);
+        seq = SEQ_MAX(seq, stream->base_seq);
         SCLogDebug("seq %u, end %u", seq, end);
 
         uint32_t pkt_off = seq - pkt_seq;
@@ -145,8 +146,8 @@ void StreamTcpInlineSegmentReplacePacket(const TcpStream *stream,
     uint32_t seq = (SEQ_LT(pseq, tseq)) ? tseq : pseq;
     SCLogDebug("seq %u, end %u", seq, end);
 
-    uint16_t poff = seq - pseq;
-    uint16_t toff = seq - tseq;
+    uint32_t poff = seq - pseq;
+    uint32_t toff = seq - tseq;
     SCLogDebug("poff %u, toff %u", poff, toff);
 
     uint32_t range = end - seq;
