@@ -24,10 +24,8 @@
 #ifndef __THREADVARS_H__
 #define __THREADVARS_H__
 
-#include "util-affinity.h"
 #include "tm-queues.h"
 #include "counters.h"
-#include "threads.h"
 #include "packet-queue.h"
 #include "util-atomic.h"
 
@@ -50,10 +48,11 @@ struct TmSlot_;
 #define THV_FLOW_LOOP           BIT_U32(10) /**< thread is in flow shutdown loop */
 
 /** signal thread's capture method to create a fake packet to force through
- *  the engine. This is to force timely handling of maintenance taks like
+ *  the engine. This is to force timely handling of maintenance tasks like
  *  rule reloads even if no packets are read by the capture method. */
 #define THV_CAPTURE_INJECT_PKT  BIT_U32(11)
 #define THV_DEAD                BIT_U32(12) /**< thread has been joined with pthread_join() */
+#define THV_RUNNING             BIT_U32(13) /**< thread is running */
 
 /** \brief Per thread variable structure */
 typedef struct ThreadVars_ {
@@ -80,7 +79,7 @@ typedef struct ThreadVars_ {
     uint8_t tmm_flags;
 
     uint8_t cap_flags; /**< Flags to indicate the capabilities of all the
-                            TmModules resgitered under this thread */
+                            TmModules registered under this thread */
     uint8_t inq_id;
     uint8_t outq_id;
 
@@ -106,8 +105,10 @@ typedef struct ThreadVars_ {
     void *outctx;
     void (*tmqh_out)(struct ThreadVars_ *, struct Packet_ *);
 
-    /** queue for decoders to temporarily store extra packets they
-     *  generate. */
+    /** Queue for decoders to temporarily store extra packets they
+     *  generate. These packets are generated as part of the tunnel
+     *  handling, and are processed directly after the "real" packet
+     *  from the current position in the pipeline. */
     PacketQueueNoLock decode_pq;
 
     /** Stream packet queue for flow time out injection. Either a pointer to the
