@@ -56,6 +56,12 @@ typedef struct TmModule_ {
     /** terminates the capture loop in PktAcqLoop */
     TmEcode (*PktAcqBreakLoop)(ThreadVars *, void *);
 
+    /** does a thread still have tasks to complete before it can be killed?
+     *  \retval bool
+     *  \param tv threadvars
+     *  \param thread_data thread module thread data (e.g. FlowWorkerThreadData for FlowWorker) */
+    bool (*ThreadBusy)(ThreadVars *tv, void *thread_data);
+
     TmEcode (*Management)(ThreadVars *, void *);
 
     /** global Init/DeInit */
@@ -64,8 +70,8 @@ typedef struct TmModule_ {
 #ifdef UNITTESTS
     void (*RegisterTests)(void);
 #endif
-    uint8_t cap_flags;   /**< Flags to indicate the capability requierment of
-                             the given TmModule */
+    uint8_t cap_flags; /**< Flags to indicate the capability requirement of
+                           the given TmModule */
     /* Other flags used by the module */
     uint8_t flags;
 } TmModule;
@@ -93,8 +99,9 @@ int TmModuleGetIDForTM(TmModule *tm);
 TmEcode TmModuleRegister(char *name, int (*module_func)(ThreadVars *, Packet *, void *));
 void TmModuleDebugList(void);
 void TmModuleRegisterTests(void);
+#ifdef PROFILING
 const char * TmModuleTmmIdToString(TmmId id);
-
+#endif
 void TmModuleRunInit(void);
 void TmModuleRunDeInit(void);
 
