@@ -25,12 +25,11 @@
 #include "suricata-common.h"
 #define _THREAD_AFFINITY
 #include "util-affinity.h"
+#include "conf.h"
+#include "runmodes.h"
 #include "util-cpu.h"
 #include "util-byte.h"
-#include "conf.h"
-#include "threads.h"
-#include "queue.h"
-#include "runmodes.h"
+#include "util-debug.h"
 
 ThreadsAffinityType thread_affinity[MAX_CPU_SET] = {
     {
@@ -115,41 +114,27 @@ void BuildCpusetWithCallback(const char *name, ConfNode *node,
             char *end;
             a = strtoul(lnode->val, &end, 10);
             if (end != sep) {
-                SCLogError(SC_ERR_INVALID_ARGUMENT,
-                        "%s: invalid cpu range (start invalid): \"%s\"",
-                        name,
-                        lnode->val);
+                SCLogError("%s: invalid cpu range (start invalid): \"%s\"", name, lnode->val);
                 exit(EXIT_FAILURE);
             }
             b = strtol(sep + 1, &end, 10);
             if (end != sep + strlen(sep)) {
-                SCLogError(SC_ERR_INVALID_ARGUMENT,
-                        "%s: invalid cpu range (end invalid): \"%s\"",
-                        name,
-                        lnode->val);
+                SCLogError("%s: invalid cpu range (end invalid): \"%s\"", name, lnode->val);
                 exit(EXIT_FAILURE);
             }
             if (a > b) {
-                SCLogError(SC_ERR_INVALID_ARGUMENT,
-                        "%s: invalid cpu range (bad order): \"%s\"",
-                        name,
-                        lnode->val);
+                SCLogError("%s: invalid cpu range (bad order): \"%s\"", name, lnode->val);
                 exit(EXIT_FAILURE);
             }
             if (b > max) {
-                SCLogError(SC_ERR_INVALID_ARGUMENT,
-                           "%s: upper bound (%ld) of cpu set is too high, only %d cpu(s)",
-                           name,
-                           b, max + 1);
+                SCLogError("%s: upper bound (%ld) of cpu set is too high, only %d cpu(s)", name, b,
+                        max + 1);
             }
         } else {
             char *end;
             a = strtoul(lnode->val, &end, 10);
             if (end != lnode->val + strlen(lnode->val)) {
-                SCLogError(SC_ERR_INVALID_ARGUMENT,
-                        "%s: invalid cpu range (not an integer): \"%s\"",
-                        name,
-                        lnode->val);
+                SCLogError("%s: invalid cpu range (not an integer): \"%s\"", name, lnode->val);
                 exit(EXIT_FAILURE);
             }
             b = a;
@@ -211,7 +196,7 @@ void AffinitySetupLoadFromConfig(void)
         ConfNode *nprio = NULL;
 
         if (taf == NULL) {
-            FatalError(SC_ERR_FATAL, "unknown cpu-affinity type");
+            FatalError("unknown cpu-affinity type");
         } else {
             SCLogConfig("Found affinity definition for \"%s\"", setname);
         }
@@ -258,7 +243,7 @@ void AffinitySetupLoadFromConfig(void)
                 } else if (!strcmp(node->val, "high")) {
                     taf->prio = PRIO_HIGH;
                 } else {
-                    FatalError(SC_ERR_FATAL, "unknown cpu_affinity prio");
+                    FatalError("unknown cpu_affinity prio");
                 }
                 SCLogConfig("Using default prio '%s' for set '%s'",
                         node->val, setname);
@@ -272,18 +257,19 @@ void AffinitySetupLoadFromConfig(void)
             } else if (!strcmp(node->val, "balanced")) {
                 taf->mode_flag = BALANCED_AFFINITY;
             } else {
-                FatalError(SC_ERR_FATAL, "unknown cpu_affinity node");
+                FatalError("unknown cpu_affinity node");
             }
         }
 
         node = ConfNodeLookupChild(affinity->head.tqh_first, "threads");
         if (node != NULL) {
             if (StringParseUint32(&taf->nb_threads, 10, 0, (const char *)node->val) < 0) {
-                FatalError(SC_ERR_INVALID_ARGUMENT, "invalid value for threads "
-                           "count: '%s'", node->val);
+                FatalError("invalid value for threads "
+                           "count: '%s'",
+                        node->val);
             }
             if (! taf->nb_threads) {
-                FatalError(SC_ERR_FATAL, "bad value for threads count");
+                FatalError("bad value for threads count");
             }
         }
     }
@@ -294,9 +280,9 @@ void AffinitySetupLoadFromConfig(void)
  * \brief Return next cpu to use for a given thread family
  * \retval the cpu to used given by its id
  */
-int AffinityGetNextCPU(ThreadsAffinityType *taf)
+uint16_t AffinityGetNextCPU(ThreadsAffinityType *taf)
 {
-    int ncpu = 0;
+    uint16_t ncpu = 0;
 #if !defined __CYGWIN__ && !defined OS_WIN32 && !defined __OpenBSD__ && !defined sun
     int iter = 0;
     SCMutexLock(&taf->taf_mutex);
@@ -309,8 +295,8 @@ int AffinityGetNextCPU(ThreadsAffinityType *taf)
         }
     }
     if (iter == 2) {
-        SCLogError(SC_ERR_INVALID_ARGUMENT, "cpu_set does not contain "
-                "available cpus, cpu affinity conf is invalid");
+        SCLogError("cpu_set does not contain "
+                   "available cpus, cpu affinity conf is invalid");
     }
     taf->lcpu = ncpu + 1;
     if (taf->lcpu >= UtilCpuGetNumProcessorsOnline())
@@ -320,3 +306,59 @@ int AffinityGetNextCPU(ThreadsAffinityType *taf)
 #endif /* OS_WIN32 and __OpenBSD__ */
     return ncpu;
 }
+
+uint16_t UtilAffinityGetAffinedCPUNum(ThreadsAffinityType *taf)
+{
+    uint16_t ncpu = 0;
+#if !defined __CYGWIN__ && !defined OS_WIN32 && !defined __OpenBSD__ && !defined sun
+    SCMutexLock(&taf->taf_mutex);
+    for (int i = UtilCpuGetNumProcessorsOnline(); i >= 0; i--)
+        if (CPU_ISSET(i, &taf->cpu_set))
+            ncpu++;
+    SCMutexUnlock(&taf->taf_mutex);
+#endif
+    return ncpu;
+}
+
+#ifdef HAVE_DPDK
+/**
+ * Find if CPU sets overlap
+ * \return 1 if CPUs overlap, 0 otherwise
+ */
+uint16_t UtilAffinityCpusOverlap(ThreadsAffinityType *taf1, ThreadsAffinityType *taf2)
+{
+    ThreadsAffinityType tmptaf;
+    CPU_ZERO(&tmptaf);
+    SCMutexInit(&tmptaf.taf_mutex, NULL);
+
+    cpu_set_t tmpcset;
+
+    SCMutexLock(&taf1->taf_mutex);
+    SCMutexLock(&taf2->taf_mutex);
+    CPU_AND(&tmpcset, &taf1->cpu_set, &taf2->cpu_set);
+    SCMutexUnlock(&taf2->taf_mutex);
+    SCMutexUnlock(&taf1->taf_mutex);
+
+    for (int i = UtilCpuGetNumProcessorsOnline(); i >= 0; i--)
+        if (CPU_ISSET(i, &tmpcset))
+            return 1;
+    return 0;
+}
+
+/**
+ * Function makes sure that CPUs of different types don't overlap by excluding
+ * one affinity type from the other
+ * \param mod_taf - CPU set to be modified
+ * \param static_taf - static CPU set to be used only for evaluation
+ */
+void UtilAffinityCpusExclude(ThreadsAffinityType *mod_taf, ThreadsAffinityType *static_taf)
+{
+    cpu_set_t tmpset;
+    SCMutexLock(&mod_taf->taf_mutex);
+    SCMutexLock(&static_taf->taf_mutex);
+    CPU_XOR(&tmpset, &mod_taf->cpu_set, &static_taf->cpu_set);
+    SCMutexUnlock(&static_taf->taf_mutex);
+    mod_taf->cpu_set = tmpset;
+    SCMutexUnlock(&mod_taf->taf_mutex);
+}
+#endif /* HAVE_DPDK */
