@@ -21,10 +21,9 @@
  * \author Eric Leblond <eric@regit.org>
  */
 
-
 #include "suricata-common.h"
-#include "suricata.h"
 #include "util-bpf.h"
+#include "threads.h"
 #include "conf.h"
 #include "util-debug.h"
 
@@ -51,8 +50,6 @@ void ConfSetBPFFilter(
     }
 }
 
-#if !defined __OpenBSD__
-
 /** protect bpf filter build, as it is not thread safe */
 static SCMutex bpf_set_filter_lock = SCMUTEX_INITIALIZER;
 
@@ -97,5 +94,3 @@ int SCBPFCompile(int snaplen_arg, int linktype_arg, struct bpf_program *program,
 
     return (ret);
 }
-
-#endif /* Not __OpenBSD__ */
