@@ -18,7 +18,9 @@
 #ifndef __UTIL_HASH_STRING_H__
 #define __UTIL_HASH_STRING_H__
 
-uint32_t StringHashDjb2(uint8_t *data, uint32_t datalen);
+#include "util-hash.h"
+
+uint32_t StringHashDjb2(const uint8_t *data, uint32_t datalen);
 uint32_t StringHashFunc(HashTable *ht, void *data, uint16_t datalen);
 char StringHashCompareFunc(void *data1, uint16_t datalen1,
                            void *data2, uint16_t datalen2);
