@@ -25,7 +25,7 @@
 #include "util-device.h"
 
 int GetIfaceMTU(const char *pcap_dev);
-int GetIfaceMaxPacketSize(const char *pcap_dev);
+int GetIfaceMaxPacketSize(LiveDevice *ld);
 int GetIfaceOffloading(const char *dev, int csum, int other);
 int GetIfaceRSSQueuesNum(const char *pcap_dev);
 #ifdef SIOCGIFFLAGS
